@@ -32,16 +32,18 @@
 /* Define this if `struct sockaddr' includes sa_len */
 #undef SOCKADDR_HAS_SA_LEN
 
+/* Define if getlogin has POSIX flavour, as opposed to BSD */
+#undef POSIX_GETLOGIN
+
 /* define if getcwd() is broken (such as in SunOS) */
 #undef BROKEN_GETCWD
 
 @BOTTOM@
 
-#ifdef __STDC__
-#define RCSID(msg) static char *const rcsid[] = { (char *)rcsid, "@(#)" msg }
-#else
-#define RCSID(msg) static char *rcsid[] = { (char *)rcsid, msg }
-#endif
+#define RCSID(msg) \
+static char *foo_version(void) { extern char *krb4_version; \
+				 foo_version(); return krb4_version; } \
+static char *const rcsid[] = { (char *)rcsid, "@(#)" msg } \
 
 /*
  * Set ORGANIZATION to be the desired organization string printed
@@ -66,10 +68,6 @@
 #define K_LOGFIL	"/var/log/kpropd.log"
 #endif
 
-/* This enables experimental stuff in kadmind, not yet tested (need a
- * multihomed server to test it). Tell bg@sics.se if it works. */
-#define MULTIHOMED_KADMIN
-
 /* Maximum values on all known systems */
 #define MaxHostNameLen (64+4)
 #define MaxPathLen (1024+4)
