@@ -15,13 +15,13 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: kdb_edit.c,v 1.13 1996/03/25 13:11:04 bg Exp $");
+RCSID("$Id: kdb_edit.c,v 1.17 1996/06/12 10:14:40 bg Exp $");
 
 #ifdef DEBUG
 extern  kerb_debug;
 #endif
 
-#define zaptime(foo) bzero((char *)(foo), sizeof(*(foo)))
+#define zaptime(foo) memset((foo), 0, sizeof(*(foo)))
 
 static char    prog[32];
 char   *progname = prog;
@@ -102,7 +102,12 @@ change_principal(void)
 	strcpy(principal_data[0].instance, input_instance);
 	principal_data[0].old = NULL;
 	principal_data[0].exp_date = default_princ.exp_date;
-	principal_data[0].max_life = default_princ.max_life;
+	if (strcmp(input_instance, "admin") == 0)
+	  principal_data[0].max_life = 1 + (CLOCK_SKEW/(5*60)); /*5+5 minutes*/
+	else if (strcmp(input_instance, "root") == 0)
+	  principal_data[0].max_life = 96; /* 8 hours */
+	else
+	  principal_data[0].max_life = default_princ.max_life;
 	principal_data[0].attributes = default_princ.attributes;
 	principal_data[0].kdc_key_ver = (unsigned char) master_key_version;
 	principal_data[0].key_version = 0; /* bumped up later */
@@ -126,8 +131,8 @@ change_principal(void)
 		 * for the qualifier clause of the replace 
 		 */
 		principal_data[i].old = (char *) &old_principal;
-		bcopy(&principal_data[i], &old_principal,
-		      sizeof(old_principal));
+		memcpy(&old_principal, &principal_data[i],
+		       sizeof(old_principal));
 		printf("\nChange password [n] ? ");
 		n_gets(temp, sizeof(temp));
 		if (strcmp("y", temp) && strcmp("Y", temp))
@@ -139,8 +144,9 @@ change_principal(void)
 		placebo_read_pw_string(pw_str, sizeof pw_str,
 		    "\nNew Password: ", TRUE);
 #else
-                des_read_pw_string(pw_str, sizeof pw_str,
-			"\nNew Password: ", TRUE);
+                if(des_read_pw_string(pw_str, sizeof pw_str,
+			"\nNew Password: ", TRUE))
+		    continue;
 #endif
 		if (   strcmp(pw_str, "RANDOM") == 0
 		    || strcmp(pw_str, "") == 0) {
@@ -149,20 +155,20 @@ change_principal(void)
 		    if (!strcmp("n", temp) || !strcmp("N", temp)) {
 			/* no, use literal */
 #ifdef NOENCRYPTION
-			bzero(new_key, sizeof(des_cblock));
+			memset(new_key, 0, sizeof(des_cblock));
 			new_key[0] = 127;
 #else
 			des_string_to_key(pw_str, &new_key);
 #endif
-			bzero(pw_str, sizeof pw_str);	/* "RANDOM" */
+			memset(pw_str, 0, sizeof pw_str);	/* "RANDOM" */
 		    } else {
 #ifdef NOENCRYPTION
-			bzero(new_key, sizeof(des_cblock));
+			memset(new_key, 0, sizeof(des_cblock));
 			new_key[0] = 127;
 #else
 			des_new_random_key(&new_key);
 #endif
-			bzero(pw_str, sizeof pw_str);
+			memset(pw_str, 0, sizeof pw_str);
 		    }
 		} else if (!strcmp(pw_str, "NULL")) {
 		    printf("\nNull Key [y] ? ");
@@ -170,12 +176,12 @@ change_principal(void)
 		    if (!strcmp("n", temp) || !strcmp("N", temp)) {
 			/* no, use literal */
 #ifdef NOENCRYPTION
-			bzero(new_key, sizeof(des_cblock));
+			memset(new_key, 0, sizeof(des_cblock));
 			new_key[0] = 127;
 #else
 			des_string_to_key(pw_str, &new_key);
 #endif
-			bzero(pw_str, sizeof pw_str);	/* "NULL" */
+			memset(pw_str, 0, sizeof pw_str);	/* "NULL" */
 		    } else {
 
 			principal_data[i].key_low = 0;
@@ -184,12 +190,12 @@ change_principal(void)
 		    }
 		} else {
 #ifdef NOENCRYPTION
-		    bzero(new_key, sizeof(des_cblock));
+		    memset(new_key, 0, sizeof(des_cblock));
 		    new_key[0] = 127;
 #else
 		    des_string_to_key(pw_str, &new_key);
 #endif
-		    bzero(pw_str, sizeof pw_str);
+		    memset(pw_str, 0, sizeof pw_str);
 		}
 
 		/* seal it under the kerberos master key */
@@ -199,7 +205,7 @@ change_principal(void)
 		copy_from_key(new_key,
 			      &principal_data[i].key_low,
 			      &principal_data[i].key_high);
-		bzero(new_key, sizeof(new_key));
+		memset(new_key, 0, sizeof(new_key));
 	null_key:
 		/* set master key version */
 		principal_data[i].kdc_key_ver =
@@ -302,8 +308,8 @@ change_principal(void)
 	    }
 
 
-	    bzero(&principal_data[i].key_low, 4);
-	    bzero(&principal_data[i].key_high, 4);
+	    memset(&principal_data[i].key_low, 0, 4);
+	    memset(&principal_data[i].key_high, 0, 4);
 	    fflush(stdout);
 	    break;
 	}
@@ -319,12 +325,12 @@ static void
 cleanup(void)
 {
 
-    bzero(master_key, sizeof(master_key));
-    bzero(session_key, sizeof(session_key));
-    bzero(master_key_schedule, sizeof(master_key_schedule));
-    bzero(principal_data, sizeof(principal_data));
-    bzero(new_key, sizeof(new_key));
-    bzero(pw_str, sizeof(pw_str));
+    memset(master_key, 0, sizeof(master_key));
+    memset(session_key, 0, sizeof(session_key));
+    memset(master_key_schedule, 0, sizeof(master_key_schedule));
+    memset(principal_data, 0, sizeof(principal_data));
+    memset(new_key, 0, sizeof(new_key));
+    memset(pw_str, 0, sizeof(pw_str));
 }
 
 int
