@@ -10,7 +10,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: kdb_init.c,v 1.13 1996/03/25 13:11:06 bg Exp $");
+RCSID("$Id: kdb_init.c,v 1.15 1996/05/29 23:23:12 assar Exp $");
 
 enum ap_op {
     NULL_KEY,			/* setup null keys */
@@ -32,7 +32,7 @@ add_principal(char *name, char *instance, enum ap_op aap_op)
     struct tm *tm;
     des_cblock new_key;
 
-    bzero(&principal, sizeof(principal));
+    memset(&principal, 0, sizeof(principal));
     strncpy(principal.name, name, ANAME_SZ);
     strncpy(principal.instance, instance, INST_SZ);
     switch (aap_op) {
@@ -42,7 +42,7 @@ add_principal(char *name, char *instance, enum ap_op aap_op)
 	break;
     case RANDOM_KEY:
 #ifdef NOENCRYPTION
-	bzero(new_key, sizeof(des_cblock));
+        memset(new_key, 0, sizeof(des_cblock));
 	new_key[0] = 127;
 #else
 	des_new_random_key(&new_key);
@@ -50,10 +50,10 @@ add_principal(char *name, char *instance, enum ap_op aap_op)
 	kdb_encrypt_key (&new_key, &new_key, &master_key, master_key_schedule,
 			 DES_ENCRYPT);
 	copy_from_key(new_key, &principal.key_low, &principal.key_high);
-	bzero(new_key, sizeof(new_key));
+	memset(new_key, 0, sizeof(new_key));
 	break;
     case MASTER_KEY:
-	bcopy (master_key, new_key, sizeof (des_cblock));
+	memcpy(new_key, master_key, sizeof (des_cblock));
 	kdb_encrypt_key (&new_key, &new_key, &master_key, master_key_schedule,
 			 DES_ENCRYPT);
 	copy_from_key(new_key, &principal.key_low, &principal.key_high);
@@ -78,9 +78,9 @@ add_principal(char *name, char *instance, enum ap_op aap_op)
         return -1;		/* FAIL */
     
     /* let's play it safe */
-    bzero (new_key, sizeof (des_cblock));
-    bzero (&principal.key_low, 4);
-    bzero (&principal.key_high, 4);
+    memset(new_key, 0, sizeof (des_cblock));
+    memset(&principal.key_low, 0, 4);
+    memset(&principal.key_high, 0, 4);
     return 0;
 }
 
@@ -107,7 +107,7 @@ main(int argc, char **argv)
     /* Do this first, it'll fail if the database exists */
     if ((code = kerb_db_create(database)) != 0) {
 	fprintf(stderr, "Couldn't create database %s: %s\n", database,
-		k_strerror(code));
+		strerror(code));
 	exit(1);
     }
     kerb_db_set_name(database);
@@ -171,7 +171,7 @@ main(int argc, char **argv)
     }
 
     /* play it safe */
-    bzero (master_key, sizeof (des_cblock));
-    bzero (master_key_schedule, sizeof (des_key_schedule));
+    memset(master_key, 0, sizeof (des_cblock));
+    memset(master_key_schedule, 0, sizeof (des_key_schedule));
     exit(0);
 }
