@@ -15,7 +15,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: kdb_util.c,v 1.12 1996/03/25 13:11:08 bg Exp $");
+RCSID("$Id: kdb_util.c,v 1.22 1996/06/06 01:01:45 joda Exp $");
 
 static char *prog; 
 
@@ -24,7 +24,7 @@ Principal aprinc;
 static des_cblock master_key, new_master_key;
 static des_key_schedule master_key_schedule, new_master_key_schedule;
 
-#define zaptime(foo) bzero((char *)(foo), sizeof(*(foo)))
+#define zaptime(foo) memset((foo), 0, sizeof(*(foo)))
 
 /* cv_key is a procedure which takes a principle and changes its key, 
    either for a new method of encrypting the keys, or a new master key.
@@ -143,6 +143,63 @@ dump_db (char *db_file, FILE *output_file, void (*cv_key) (Principal *))
     return fflush(output_file);
 }
 
+static int
+add_file(void *db, FILE *file)
+{
+    int ret;
+    int lineno = 0;
+    char line[1024];
+    unsigned long key[2]; /* yes, long */
+    Principal pr;
+    
+    char exp_date[64], mod_date[64];
+    
+    int life, kkvno, kvno;
+    
+    while(1){
+	memset(&pr, 0, sizeof(pr));
+	errno = 0;
+	if(fgets(line, sizeof(line), file) == NULL){
+	    if(errno != 0){
+		perror("fgets");
+		return 1;
+	    }
+	    break;
+	}
+	lineno++;
+	ret = sscanf(line, "%s %s %d %d %d %hd %lx %lx %s %s %s %s",
+		     pr.name, pr.instance,
+		     &life, &kkvno, &kvno,
+		     &pr.attributes,
+		     &key[0], &key[1],
+		     exp_date, mod_date,
+		     pr.mod_name, pr.mod_instance);
+	if(ret != 12){
+	    fprintf(stderr, "Line %d malformed (ignored)\n", lineno);
+	    continue;
+	}
+	pr.key_low = ntohl (key[0]);
+	pr.key_high = ntohl (key[1]);
+	pr.max_life = life;
+	pr.kdc_key_ver = kkvno;
+	pr.key_version = kvno;
+	pr.exp_date = time_explode(exp_date);
+	pr.mod_date = time_explode(mod_date);
+	if (pr.instance[0] == '*')
+	    pr.instance[0] = 0;
+	if (pr.mod_name[0] == '*')
+	    pr.mod_name[0] = 0;
+	if (pr.mod_instance[0] == '*')
+	    pr.mod_instance[0] = 0;
+	if (kerb_db_update(db, &pr, 1) != 1) {
+	    fprintf(stderr, "Couldn't store %s.%s: %s; load aborted\n",
+		    pr.name, pr.instance, strerror(errno));
+	    return 1;
+	}
+    }
+    return 0;
+}
+
 static void
 load_db (char *db_file, FILE *input_file)
 {
@@ -160,54 +217,22 @@ load_db (char *db_file, FILE *input_file)
     /* Create the database */
     if ((code = kerb_db_create(temp_db_file)) != 0) {
 	fprintf(stderr, "Couldn't create temp database %s: %s\n",
-		temp_db_file, k_strerror(code));
+		temp_db_file, strerror(code));
 	exit(1);
     }
     kerb_db_set_name(temp_db_file);
     db = kerb_db_begin_update();
     if (db == NULL) {
 	fprintf(stderr, "Couldn't open temp database %s; %s\n",
-		temp_db_file, k_strerror(code));
+		temp_db_file, strerror(code));
 	exit(1);
     }
-    for (;;) {			/* explicit break on eof from fscanf */
-        u_long key_lo, key_hi;	/* Must match format string */
-	bzero((char *)&aprinc, sizeof(aprinc));
-	if (fscanf(input_file,
-		   "%s %s %d %d %d %hd %lx %lx %s %s %s %s\n",
-		   aprinc.name,
-		   aprinc.instance,
-		   &temp1,
-		   &temp2,
-		   &temp3,
-		   &aprinc.attributes,
-		   &key_lo,
-		   &key_hi,
-		   exp_date_str,
-		   mod_date_str,
-		   aprinc.mod_name,
-		   aprinc.mod_instance) == EOF)
-	    break;
-	aprinc.key_low = ntohl (key_lo);
-	aprinc.key_high = ntohl (key_hi);
-	aprinc.max_life = (unsigned char) temp1;
-	aprinc.kdc_key_ver = (unsigned char) temp2;
-	aprinc.key_version = (unsigned char) temp3;
-	aprinc.exp_date = time_explode(exp_date_str);
-	aprinc.mod_date = time_explode(mod_date_str);
-	if (aprinc.instance[0] == '*')
-	    aprinc.instance[0] = '\0';
-	if (aprinc.mod_name[0] == '*')
-	    aprinc.mod_name[0] = '\0';
-	if (aprinc.mod_instance[0] == '*')
-	    aprinc.mod_instance[0] = '\0';
-	if (kerb_db_update(db, &aprinc, 1) != 1) {
-	    fprintf(stderr, "Couldn't store %s.%s: %s; load aborted\n",
-		    aprinc.name, aprinc.instance,
-		    k_strerror(errno));
-	    exit(1);
-	};
+    
+    if(add_file(db, input_file)){
+	fprintf(stderr, "Load aborted.\n");
+	exit(1);
     }
+
     kerb_db_end_update(db);
     if ((code = kerb_db_rename(temp_db_file, db_file)) != 0)
 	perror("database rename failed");
@@ -215,6 +240,24 @@ load_db (char *db_file, FILE *input_file)
     free(temp_db_file);
 }
 
+static void
+merge_db(char *db_file, FILE *input_file)
+{
+    void *db;
+    int ret;
+    
+    db = kerb_db_begin_update();
+    if(db == NULL){
+	fprintf(stderr, "Couldn't open database: %s\n", strerror(ret));
+	exit(1);
+    }
+    if(add_file(db, input_file)){
+	fprintf(stderr, "Merge aborted!\n");
+    }
+    kerb_db_end_update(db);
+}
+
+
 /*ARGSUSED*/
 static void
 update_ok_file (char *file_name)
@@ -255,7 +298,7 @@ convert_key_new_master (Principal *p)
      since that's changing */
   if ((strncmp (p->name, KERB_M_NAME, ANAME_SZ) == 0) &&
       (strncmp (p->instance, KERB_M_INST, INST_SZ) == 0)) {
-    bcopy((char *)new_master_key, (char *) key, sizeof (des_cblock));
+    memcpy (key, new_master_key, sizeof(des_cblock));
     (p->key_version)++;
   } else {
     copy_to_key(&p->key_low, &p->key_high, key);
@@ -265,7 +308,7 @@ convert_key_new_master (Principal *p)
   kdb_encrypt_key (&key, &key, &new_master_key, new_master_key_schedule, DES_ENCRYPT);
 
   copy_from_key(key, &(p->key_low), &(p->key_high));
-  bzero((char *)key, sizeof (key));  /* a little paranoia ... */
+  memset(key, 0, sizeof (key));  /* a little paranoia ... */
 
   (p->kdc_key_ver)++;
 }
@@ -273,10 +316,10 @@ convert_key_new_master (Principal *p)
 static void
 clear_secrets (void)
 {
-  bzero((char *)master_key, sizeof (des_cblock));
-  bzero((char *)master_key_schedule, sizeof (des_key_schedule));
-  bzero((char *)new_master_key, sizeof (des_cblock));
-  bzero((char *)new_master_key_schedule, sizeof (des_key_schedule));
+  memset(master_key, 0, sizeof (des_cblock));
+  memset(master_key_schedule, 0, sizeof (des_key_schedule));
+  memset(new_master_key, 0, sizeof (des_cblock));
+  memset(new_master_key_schedule, 0, sizeof (des_key_schedule));
 }
 
 static void
@@ -337,7 +380,7 @@ convert_key_old_db (Principal *p)
   kdb_encrypt_key (&key, &key, &master_key, master_key_schedule, DES_ENCRYPT);
 
   copy_from_key(key, &(p->key_low), &(p->key_high));
-  bzero((char *)key, sizeof (key));  /* a little paranoia ... */
+  memset(key, 0, sizeof (key));  /* a little paranoia ... */
 }
 
 static void
@@ -379,9 +422,9 @@ convert_old_format_db (char *db_file, FILE *out)
 	master_key_schedule,(des_cblock *)master_key_schedule, DES_DECRYPT);
 #endif
   /* the decrypted database key had better equal the master key */
-  n = bcmp((char *) master_key, (char *) key_from_db,
-	   sizeof(master_key));
-  bzero((char *)key_from_db, sizeof(key_from_db));
+
+  n = memcmp(master_key, key_from_db, sizeof(master_key));
+  memset(key_from_db, 0, sizeof(key_from_db));
 
   if (n) {
     fprintf(stderr, "\n\07\07verify_master_key: Invalid master key, ");
@@ -398,9 +441,11 @@ convert_old_format_db (char *db_file, FILE *out)
 int
 main(int argc, char **argv)
 {
+    int ret;
     FILE   *file;
     enum {
 	OP_LOAD,
+	OP_MERGE,
 	OP_DUMP,
 	OP_SLAVE_DUMP,
 	OP_NEW_MASTER,
@@ -411,22 +456,31 @@ main(int argc, char **argv)
     prog = argv[0];
     
     if (argc != 3 && argc != 4) {
-	fprintf(stderr, "Usage: %s operation file-name [database name].\n",
+	fprintf(stderr, "Usage: %s operation file [database name].\n",
 		argv[0]);
+	fprintf(stderr, "Operation is one of: load, merge, dump, slave_dump, new_master_key\n");
 	exit(1);
     }
     if (argc == 3)
 	db_name = DBM_FILE;
     else
 	db_name = argv[3];
+    
+    ret = kerb_db_set_name (db_name);
+    
+    /* this makes starting slave servers ~14.3 times easier */
+    if(ret && strcmp(argv[1], "load") == 0)
+       ret = kerb_db_create (db_name);
 
-    if (kerb_db_set_name (db_name) != 0) {
+    if(ret){
 	perror("Can't open database");
 	exit(1);
     }
-    
+
     if (!strcmp(argv[1], "load"))
 	op = OP_LOAD;
+    else if (!strcmp(argv[1], "merge"))
+	op = OP_MERGE;
     else if (!strcmp(argv[1], "dump"))
 	op = OP_DUMP;
     else if (!strcmp(argv[1], "slave_dump"))
@@ -446,7 +500,7 @@ main(int argc, char **argv)
     }
 
     file_name = argv[2];
-    file = fopen(file_name, op == OP_LOAD ? "r" : "w");
+    file = fopen(file_name, (op == OP_LOAD || op == OP_MERGE) ? "r" : "w");
     if (file == NULL) {
 	fprintf(stderr, "%s: Unable to open %s\n", prog, argv[2]);
 	(void) fflush(stderr);
@@ -475,6 +529,9 @@ main(int argc, char **argv)
     case OP_LOAD:
       load_db (db_name, file);
       break;
+    case OP_MERGE:
+	merge_db (db_name, file);
+	break;
     case OP_NEW_MASTER:
       convert_new_master_key (db_name, file);
       printf("Don't forget to do a `kdb_util load %s' to reload the database!\n", file_name);
