@@ -2,7 +2,7 @@
 
 #ifndef HAVE_FORKPTY
 
-RCSID("$Id: forkpty.c,v 1.37 1996/03/28 11:10:28 bg Exp $");
+RCSID("$Id: forkpty.c,v 1.38 1996/06/08 22:52:31 joda Exp $");
 
 /* Systems where rlogind has been tested */
 #if 1 || (defined(sun) && !defined(__svr4__)) || defined(__hpux) || defined(__linux) || defined(__sgi__) || defined(__NetBSD__) || defined(_AIX)
@@ -73,6 +73,56 @@ revoke(char *line)
 }
 #endif
 
+
+static int pty_major, pty_minor;
+
+static void
+pty_scan_start(void)
+{
+    pty_major = -1;
+    pty_minor = 0;
+}
+
+static char *bsd_1 = "0123456789abcdefghijklmnopqrstuv";
+/* there are many more */
+static char *bsd_2 = "pqrstuvwxyzabcdefghijklmnoABCDEFGHIJKLMNOPQRSTUVWXYZ";
+
+static int
+pty_scan_next(char *buf)
+{
+#ifdef CRAY
+    if(++pty_major >= sysconf(_SC_CRAY_NPTY))
+	return -1;
+    sprintf(buf, "/dev/pty/%03d", pty_major);
+#else
+    if(++pty_major == strlen(bsd_1)){
+	pty_major = 0;
+	if(++pty_minor == strlen(bsd_2))
+	    return -1;
+    }
+#ifdef __hpux
+    sprintf(buf, "/dev/ptym/pty%c%c", bsd_2[pty_major], bsd_1[pty_minor]);
+#else
+    sprintf(buf, "/dev/pty%c%c", bsd_2[pty_major], bsd_1[pty_minor]);
+#endif
+#endif
+    return 0;
+}
+
+static void
+pty_scan_tty(char *buf)
+{
+#ifdef CRAY
+    sprintf(buf, "/dev/ttyp%03d", pty_major);
+#else
+#ifdef __hpux
+    sprintf(buf, "/dev/pty/tty%c%c", bsd_2[pty_major], bsd_1[pty_minor]);
+#else
+    sprintf(buf, "/dev/tty%c%c", bsd_2[pty_major], bsd_1[pty_minor]);
+#endif
+#endif
+}
+
 static int
 ptym_open(char *pts_name, int *streams_pty)
 {
@@ -108,54 +158,59 @@ ptym_open(char *pts_name, int *streams_pty)
 	return(fdm);			/* return fd of master */
     }
     
-    /* HP-UX has a different naming of their pty's */
-#ifdef __hpux
-    strcpy(pts_name, "/dev/ptym/ptyXY");
-#define pts_name_X pts_name[13]
-#define pts_name_Y pts_name[14]
-#else
-    strcpy(pts_name, "/dev/ptyXY");
-#define pts_name_X pts_name[8]
-#define pts_name_Y pts_name[9]
-#endif
-
     /* Try BSD style master ptys */
     *streams_pty = 0;
-    /* array index: 0123456789 (for references in following code) */
-    for (ptr1 = "pqrstuvwxyzPQRST"; *ptr1 != 0; ptr1++)
-	{
-	    pts_name_X = *ptr1;
-	    for (ptr2 = "0123456789abcdefghijklmnopqrstuv";
-		 *ptr2 != 0;
-		 ptr2++)
-		{
-		    pts_name_Y = *ptr2;
-		    /* Try to open master */
-		    if ( (fdm = open(pts_name, O_RDWR)) < 0)
-			continue; /* Try next pty device */
-			    
+
+    pty_scan_start();
+    
+    while(pty_scan_next(pts_name) != -1){
+	fdm = open(pts_name, O_RDWR);
+	if(fdm < 0)
+	    continue;
 #if SunOS == 4
-		    /* Avoid a bug in SunOS4 ttydriver */
-		    if (fdm > 0) {
-			int pgrp;
-			if ((ioctl(fdm, TIOCGPGRP, &pgrp) == -1)
-			    && (errno == EIO))
-			    /* All fine */;
-			else
-			    {
-				close(fdm);
-				continue;
-			    }
-		    }
-#endif
-#ifdef __hpux
-		    sprintf(pts_name, "/dev/pty/tty%c%c", *ptr1, *ptr2);
-#else
-		    pts_name[5] = 't'; /* Change "pty" to "tty" */
-#endif
-		    return fdm;	/* All done! */
-		}
+	/* Avoid a bug in SunOS4 ttydriver */
+	if (fdm > 0) {
+	    int pgrp;
+	    if ((ioctl(fdm, TIOCGPGRP, &pgrp) == -1)
+		&& (errno == EIO))
+		/* All fine */;
+	    else {
+		close(fdm);
+		continue;
+	    }
 	}
+#endif
+	pty_scan_tty(pts_name);
+#if 0 /* CRAY */
+	/* this is some magic from the telnet code */
+	{
+	    struct stat sb;
+	    if(stat(pts_name, &sb) < 0) {
+		close(fdm);
+		continue;
+	    }
+	    if(sb.st_uid || sb.st_gid || sb.st_mode != 0600) {
+		chown(pts_name, 0, 0);
+		chmod(pts_name, 0600);
+		close(fdm);
+		fdm = open(myline, 2);
+		if (fdm < 0)
+		    continue;
+	    }
+	}
+	/*
+	 * Now it should be safe...check for accessability.
+	 */
+	if (access(line, 6) == 0)
+	    return fdm;
+	else {
+	    /* no tty side to pty so skip it */
+	    close(p);
+	}
+#endif
+	return fdm;	/* All done! */
+    }
+    
     /* We failed to find BSD style pty */
     errno = ENOENT;
     return -1;
