@@ -39,7 +39,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: login.c,v 1.60 1996/04/24 09:19:14 bg Exp $");
+RCSID("$Id: login.c,v 1.66 1996/06/15 09:41:40 assar Exp $");
 
 #ifdef	xSKEY			/* Don't bother to find this header file. */
 #include <skey.h>
@@ -91,6 +91,9 @@ int	failures;
 char	term[64], *envinit[1], *hostname, *username, *tty;
 
 static  char rusername[100], lusername[100];
+#ifdef HAVE_SHADOW_H
+static  struct spwd *spwd;
+#endif
 
 static int
 change_passwd(struct passwd  *who)
@@ -181,7 +184,7 @@ main(argc, argv)
 			    exit(1);
                         }
 			if (uid)
-				errx(1, "-h option: %s", k_strerror(EPERM));
+				errx(1, "-h option: %s", strerror(EPERM));
 			hflag = 1;
 			strncpy(full_hostname, optarg, sizeof(full_hostname)-1);
 			if (domain && (p = strchr(optarg, '.')) &&
@@ -305,7 +308,7 @@ main(argc, argv)
 		}
 		(void)strcpy(tbuf, username);
 
-		if ((pwd = getpwnam(username)) != 0)
+		if ((pwd = k_getpwnam(username)) != 0)
 			salt = pwd->pw_passwd;
 		else
 			salt = "xx";
@@ -343,7 +346,7 @@ main(argc, argv)
 
 		sprintf(prompt, "%s's Password: ", username);
 #ifdef	SKEY
-		permit_passwd = skeyaccess(username, tty,
+		permit_passwd = skeyaccess(pwd, tty,
 					   hostname ? full_hostname : NULL,
 					   NULL);
 		p = (char *) skey_getpass(prompt, pwd, permit_passwd);
@@ -372,7 +375,7 @@ main(argc, argv)
 #endif
 			rval = klogin(pwd, instance, localhost, p);
 			/* getpwnam() is not reentrant and klogin used it! */
-			pwd = getpwnam(username);
+			pwd = k_getpwnam(username);
 			if (pwd == NULL){
 			      fprintf(stderr, "unknown login %s\n", username);
 			      exit(1);
@@ -604,7 +607,7 @@ main(argc, argv)
 	    int uid = rootlogin ? 0 : pwd->pw_uid;
 	    if(setuid(uid) != 0){
 		fprintf(stderr, "Failed to setuid(%d): %s\n", 
-			uid, k_strerror(errno));
+			uid, strerror(errno));
 		if(!rootlogin)
 		    exit(1);
 	    }
@@ -624,7 +627,10 @@ main(argc, argv)
         }
 
 #ifdef SYSV_SHADOW
-        if (sysv_expire(spwd)) {
+#ifdef HAVE_GETSPNAM
+	spwd = getspnam (username);
+#endif
+        if (spwd && sysv_expire(spwd)) {
                 if (change_passwd(pwd))
                         sleepexit(0);
 		changepass = 0;
@@ -773,7 +779,7 @@ dolastlog(quiet)
 #ifdef SYSV_SHADOW
                 if (read(fd, (char *)&ll, sizeof(ll)) == sizeof(ll) &&
                     ll.ll_time != 0) {
-                        if (pwd->pw_uid && spwd->sp_inact > 0
+                        if (pwd->pw_uid && spwd && spwd->sp_inact > 0
                             && ll.ll_time / DAY + spwd->sp_inact < DAY_NOW) {
                                 printf("Your account has been inactive too long.\n");
                                 sleepexit(1);
@@ -868,7 +874,7 @@ stypeof(ttyid)
 
 static
 void
-getstr(char *buf, int cnt, char *err)
+xgetstr(char *buf, int cnt, char *err)
 {
         char ch;
  
@@ -897,13 +903,13 @@ doremotelogin(char *host)
         int code;
         char *cp;
 
-        getstr(rusername, sizeof (rusername), "remuser");
-        getstr(lusername, sizeof (lusername), "locuser");
-        getstr(term, sizeof(term), "Terminal type");
+        xgetstr(rusername, sizeof (rusername), "remuser");
+        xgetstr(lusername, sizeof (lusername), "locuser");
+        xgetstr(term, sizeof(term), "Terminal type");
 	cp = strchr(term, '/');
 	if (cp != 0)
 		*cp = 0;	/* For now ignore speed/bg */
-        pwd = getpwnam(lusername);
+        pwd = k_getpwnam(lusername);
         if (pwd == NULL)
                 return(-1);
         code = ruserok(host, (pwd->pw_uid == 0), rusername, lusername);
