@@ -35,7 +35,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rcp.c,v 1.22 1996/03/28 13:46:33 bg Exp $");
+RCSID("$Id: rcp.c,v 1.23 1996/05/12 18:45:32 joda Exp $");
 
 /* Globals */
 char *__progname;
@@ -175,7 +175,7 @@ verifydir(char *cp)
 			return;
 		errno = ENOTDIR;
 	}
-	run_err("%s: %s", cp, k_strerror(errno));
+	run_err("%s: %s", cp, strerror(errno));
 	exit(1);
 }
 
@@ -188,7 +188,7 @@ allocbuf(BUF *bp, int fd, int blksize)
 	size_t size;
 
 	if (fstat(fd, &stb) < 0) {
-		run_err("fstat: %s", k_strerror(errno), "");
+		run_err("fstat: %s", strerror(errno), "");
 		return (0);
 	}
 	size = ROUNDUP(stb.st_blksize, blksize);
@@ -202,7 +202,7 @@ allocbuf(BUF *bp, int fd, int blksize)
 		bp->buf = realloc(bp->buf, size);
 	if (bp->buf == NULL) {
 		bp->cnt = 0;
-		run_err("%s", k_strerror(errno), "");
+		run_err("%s", strerror(errno), "");
 		return (0);
 	}
 	bp->cnt = size;
@@ -287,7 +287,7 @@ source(int argc, char **argv)
 		if ((fd = open(name, O_RDONLY, 0)) < 0)
 			goto syserr;
 		if (fstat(fd, &stb)) {
-syserr:			run_err("%s: %s", name, k_strerror(errno));
+syserr:			run_err("%s: %s", name, strerror(errno));
 			goto next;
 		}
 		switch (stb.st_mode & S_IFMT) {
@@ -351,7 +351,7 @@ next:			(void)close(fd);
 		if (!haderr)
 			(void)des_write(rem, "", 1);
 		else
-			run_err("%s: %s", name, k_strerror(haderr));
+			run_err("%s: %s", name, strerror(haderr));
 		(void)response();
 	}
 }
@@ -364,7 +364,7 @@ rsource(char *name, struct stat *statp)
 	char *last, *vect[1], path[MaxPathLen];
 
 	if (!(dirp = opendir(name))) {
-		run_err("%s: %s", name, k_strerror(errno));
+		run_err("%s: %s", name, strerror(errno));
 		return;
 	}
 	last = strrchr(name, '/');
@@ -693,7 +693,7 @@ sink(int argc, char **argv)
 			need = strlen(targ) + strlen(cp) + 250;
 			if (need > cursize) {
 				if (!(namebuf = malloc(need)))
-					run_err("%s", k_strerror(errno), "");
+					run_err("%s", strerror(errno), "");
 			}
 			(void)sprintf(namebuf, "%s%s%s", targ,
 			    *targ ? "/" : "", cp);
@@ -725,7 +725,7 @@ sink(int argc, char **argv)
 				setimes = 0;
 				if (utime(np, &times) < 0)
 				    run_err("%s: set times: %s",
-					np, k_strerror(errno));
+					np, strerror(errno));
 			}
 			if (mod_flag)
 				(void)chmod(np, mode);
@@ -734,7 +734,7 @@ sink(int argc, char **argv)
 		omode = mode;
 		mode |= S_IWRITE;
 		if ((ofd = open(np, O_WRONLY|O_CREAT, mode)) < 0) {
-bad:			run_err("%s: %s", np, k_strerror(errno));
+bad:			run_err("%s: %s", np, strerror(errno));
 			continue;
 		}
 		(void)des_write(rem, "", 1);
@@ -752,7 +752,7 @@ bad:			run_err("%s: %s", np, k_strerror(errno));
 			do {
 				j = des_read(rem, cp, amt);
 				if (j <= 0) {
-					run_err("%s", j ? k_strerror(errno) :
+					run_err("%s", j ? strerror(errno) :
 					    "dropped connection", "");
 					exit(1);
 				}
@@ -778,19 +778,19 @@ bad:			run_err("%s: %s", np, k_strerror(errno));
 			wrerrno = j >= 0 ? EIO : errno; 
 		}
 		if (ftruncate(ofd, size)) {
-			run_err("%s: truncate: %s", np, k_strerror(errno));
+			run_err("%s: truncate: %s", np, strerror(errno));
 			wrerr = DISPLAYED;
 		}
 		if (pflag) {
 			if (exists || omode != mode)
 				if (fchmod(ofd, omode))
 					run_err("%s: set mode: %s",
-					    np, k_strerror(errno));
+					    np, strerror(errno));
 		} else {
 			if (!exists && omode != mode)
 				if (fchmod(ofd, omode & ~mask))
 					run_err("%s: set mode: %s",
-					    np, k_strerror(errno));
+					    np, strerror(errno));
 		}
 		(void)close(ofd);
 		(void)response();
@@ -801,13 +801,13 @@ bad:			run_err("%s: %s", np, k_strerror(errno));
 			setimes = 0;
 			if (utime(np, &times) < 0) {
 				run_err("%s: set times: %s",
-				    np, k_strerror(errno));
+				    np, strerror(errno));
 				wrerr = DISPLAYED;
 			}
 		}
 		switch(wrerr) {
 		case YES:
-			run_err("%s: %s", np, k_strerror(wrerrno));
+			run_err("%s: %s", np, strerror(wrerrno));
 			break;
 		case NO:
 			(void)des_write(rem, "", 1);
