@@ -38,7 +38,7 @@
  */
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogin.c,v 1.28 1996/03/24 16:52:19 bg Exp $");
+RCSID("$Id: rlogin.c,v 1.32 1996/05/29 23:23:22 assar Exp $");
 
 #include <termios.h>
 
@@ -227,7 +227,7 @@ done(int status)
 
 static
 RETSIGTYPE
-catch_child()
+catch_child(int foo)
 {
 	int status;
 	int pid;
@@ -285,7 +285,7 @@ oob_real()
 		for (;;) {
 			if (ioctl(rem, SIOCATMARK, &atmark) < 0) {
 				(void)fprintf(stderr, "rlogin: ioctl: %s.\n",
-				    k_strerror(errno));
+				    strerror(errno));
 				break;
 			}
 			if (atmark)
@@ -379,7 +379,7 @@ reader(void)
 			if (errno == EINTR)
 				continue;
 			(void)fprintf(stderr, "rlogin: read: %s.\n",
-			    k_strerror(errno));
+			    strerror(errno));
 			return (-1);
 		}
 	}
@@ -416,12 +416,12 @@ sendwindow(void)
 
 static
 RETSIGTYPE
-sigwinch()
+sigwinch(int foo)
 {
 	struct winsize ws;
 
 	if (get_window_size(0, &ws) == 0 &&
-	    bcmp(&ws, &winsize, sizeof(ws))) {
+	    memcmp(&ws, &winsize, sizeof(ws))) {
 		winsize = ws;
 		sendwindow();
 	}
@@ -529,7 +529,7 @@ writer(void)
 
 static
 RETSIGTYPE
-lostpeer()
+lostpeer(int foo)
 {
 	(void)signal(SIGPIPE, SIG_IGN);
 	msg("\aconnection closed.");
@@ -543,7 +543,7 @@ lostpeer()
  */
 static
 RETSIGTYPE
-sigusr1()
+sigusr1(int foo)
 {
         /*
 	 * Now we now daemon supports winsize hack,
@@ -572,7 +572,7 @@ doit(void)
 	parent = getpid();
 	child = fork();
 	if (child == -1) {
-		(void)fprintf(stderr, "rlogin: fork: %s.\n", k_strerror(errno));
+		(void)fprintf(stderr, "rlogin: fork: %s.\n", strerror(errno));
 		done(1);
 	}
 	if (child == 0) {
@@ -749,7 +749,7 @@ main(int argc, char **argv)
 		hp = gethostbyname(host);
 		if (hp != NULL && !(host = strdup(hp->h_name))) {
 			(void)fprintf(stderr, "rlogin: %s\n",
-			    k_strerror(ENOMEM));
+			    strerror(ENOMEM));
 			exit(1);
 		}
 
@@ -789,7 +789,7 @@ main(int argc, char **argv)
 	    setsockopt(rem, SOL_SOCKET, SO_DEBUG, (void *)&one,
 		       sizeof(one)) < 0)
 		(void)fprintf(stderr, "rlogin: setsockopt: %s.\n",
-		    k_strerror(errno));
+		    strerror(errno));
 #ifdef IP_TOS
 	one = IPTOS_LOWDELAY;
 	if (setsockopt(rem, IPPROTO_IP, IP_TOS, (void *)&one, sizeof(int)) < 0)
