@@ -42,7 +42,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogind.c,v 1.50 1996/04/24 07:41:11 assar Exp $");
+RCSID("$Id: rlogind.c,v 1.59 1996/06/14 00:56:35 assar Exp $");
 
 #include <termios.h>
 
@@ -98,7 +98,7 @@ u_char		tick_buf[sizeof(KTEXT_ST)];
 Key_schedule	schedule;
 int		doencrypt, retval, use_kerberos, vacuous;
 
-#define		ARGSTR			"alnkvx"
+#define		ARGSTR			"aip:lnkvxL:"
 
 char	*env[2];
 #define	NMAX 30
@@ -110,13 +110,14 @@ int	check_all = 0;
 
 struct	passwd *pwd;
 
+static const char *new_login = _PATH_LOGIN;
+
 void	doit __P((int, struct sockaddr_in *));
 int	control __P((int, char *, int));
 void	protocol __P((int, int));
 void	cleanup __P((int));
 void	fatal __P((int, const char *, int));
 int	do_rlogin __P((struct sockaddr_in *));
-void	getstr __P((char *, int, char *));
 void	setup_term __P((int));
 int	do_krb_login __P((struct sockaddr_in *));
 void	usage __P((void));
@@ -232,9 +233,9 @@ static int logout(const char *line)
 		if (!ut.ut_name[0] ||
 		    strncmp(ut.ut_line, line, sizeof(ut.ut_line)))
 			continue;
-		bzero(ut.ut_name, sizeof(ut.ut_name));
+		memset(ut.ut_name, 0, sizeof(ut.ut_name));
 #ifdef HAVE_UT_HOST
-		bzero(ut.ut_host, sizeof(ut.ut_host));
+		memset(ut.ut_host, 0, sizeof(ut.ut_host));
 #endif
 		(void)time(&ut.ut_time);
 		(void)fseek(fp, (long)-sizeof(struct utmp), SEEK_CUR);
@@ -246,6 +247,7 @@ static int logout(const char *line)
 	return(rval);
 }
 
+#ifndef HAVE_LOGWTMP
 static void
 logwtmp(const char *line, const char *name, const char *host)
 {
@@ -254,6 +256,7 @@ logwtmp(const char *line, const char *name, const char *host)
 	int fd;
 	time_t time();
 
+	memset (&ut, 0, sizeof(ut));
 	if ((fd = open(_PATH_WTMP, O_WRONLY|O_APPEND, 0)) < 0)
 		return;
 	if (!fstat(fd, &buf)) {
@@ -261,6 +264,15 @@ logwtmp(const char *line, const char *name, const char *host)
 		(void)strncpy(ut.ut_name, name, sizeof(ut.ut_name));
 #ifdef HAVE_UT_HOST
 		(void)strncpy(ut.ut_host, host, sizeof(ut.ut_host));
+#endif
+#ifdef HAVE_UT_PID
+		ut.ut_pid = getpid();
+#endif
+#ifdef HAVE_UT_TYPE
+		if(name[0])
+		  ut.ut_type = USER_PROCESS;
+		else
+		  ut.ut_type = DEAD_PROCESS;
 #endif
 		(void)time(&ut.ut_time);
 		if (write(fd, (char *)&ut, sizeof(struct utmp)) !=
@@ -269,12 +281,62 @@ logwtmp(const char *line, const char *name, const char *host)
 	}
 	(void)close(fd);
 }
+#endif
+
+static void
+wait_for_connection(char *port)
+{
+    int s;
+    int fd;
+    struct sockaddr_in sa;
+    struct sockaddr_in from;
+    int from_len;
+    struct servent *se;
+    int one = 1;
+    
+    s = socket(AF_INET, SOCK_STREAM, 0);
+    if(s < 0){
+	perror("socket");
+	exit(1);
+    }
+    
+    if(setsockopt(s, SOL_SOCKET, SO_REUSEADDR, (void *)&one, sizeof(one)) < 0){
+	perror("setsockopt");
+	exit(1);
+    }
+
+    memset(&sa, 0, sizeof(sa));
+    se = getservbyname(port, "tcp");
+    if(se)
+	sa.sin_port = se->s_port;
+    else
+	sa.sin_port = htons(atoi(port));
+    
+    sa.sin_addr.s_addr = INADDR_ANY;
+    if(bind(s, (struct sockaddr*)&sa, sizeof(sa)) < 0){
+	perror("bind");
+	exit(1);
+    }
+    listen(s, 5);
+    from_len = sizeof(from);
+    if((fd = accept(s, (struct sockaddr*)&from, &from_len)) < 0){
+	perror("accept");
+	exit(-1);
+    }
+    close(s);
+    dup2(fd, 0);
+    dup2(fd, 1);
+    if(fd > 1)
+	close(fd);
+}
 
 int main(int argc, char **argv)
 {
 	extern int __check_rhosts_file;
 	struct sockaddr_in from;
 	int ch, fromlen, on;
+	int interactive = 0;
+	char *port = NULL;
 
 	openlog("rlogind", LOG_PID | LOG_CONS, LOG_AUTH);
 
@@ -284,6 +346,12 @@ int main(int argc, char **argv)
 		case 'a':
 			check_all = 1;
 			break;
+		case 'i':
+			interactive = 1;
+			break;
+		case 'p':
+			port = optarg;
+			break;
 		case 'l':
 			__check_rhosts_file = 0;
 			break;
@@ -299,6 +367,9 @@ int main(int argc, char **argv)
 		case 'x':
 			doencrypt = 1;
 			break;
+		case 'L':
+		        new_login = optarg;
+			break;
 		case '?':
 		default:
 			usage();
@@ -311,6 +382,9 @@ int main(int argc, char **argv)
 		usage();
 		fatal(STDERR_FILENO, "only one of -k and -v allowed", 0);
 	}
+	if(interactive)
+	    wait_for_connection(port?port:use_kerberos?doencrypt?"eklogin":"klogin":"login");
+
 	fromlen = sizeof (from);
 	if (getpeername(0, (struct sockaddr *)&from, &fromlen) < 0) {
 		syslog(LOG_ERR,"Can't get peer name of remote host: %m");
@@ -355,7 +429,6 @@ void doit(int f, struct sockaddr_in *fromp)
 		fatal(f, "Remote host requires Kerberos authentication", 0);
 
 	alarm(0);
-	fromp->sin_port = ntohs((u_short)fromp->sin_port);
 	hp = gethostbyaddr((char *)&fromp->sin_addr, sizeof(struct in_addr),
 	    fromp->sin_family);
 	if (hp)
@@ -373,6 +446,7 @@ void doit(int f, struct sockaddr_in *fromp)
 		confirmed = 1;		/* we sent the null! */
 	} else
 	{
+		fromp->sin_port = ntohs((u_short)fromp->sin_port);
 		if (fromp->sin_family != AF_INET ||
 		    fromp->sin_port >= IPPORT_RESERVED ||
 		    fromp->sin_port < IPPORT_RESERVED/2) {
@@ -448,12 +522,12 @@ void doit(int f, struct sockaddr_in *fromp)
 				    kdata->pname, kdata->pinst, kdata->prealm,
 				    hostname);
 
-			execl(_PATH_LOGIN, "login", "-p",
+			execl(new_login, "login", "-p",
 			    "-h", hostname, "-f", lusername, (char *)NULL);
 		} else
-			execl(_PATH_LOGIN, "login", "-p",
+			execl(new_login, "login", "-p",
 			    "-h", hostname, lusername, (char *)NULL);
-		fatal(STDERR_FILENO, _PATH_LOGIN, 1);
+		fatal(STDERR_FILENO, new_login, 1);
 		/*NOTREACHED*/
 	}
 	/*
@@ -488,7 +562,7 @@ int control(int master, char *cp, int n)
 	if (n < 4+sizeof (w) || cp[2] != 's' || cp[3] != 's')
 		return (0);
 	oobdata[0] &= ~TIOCPKT_WINDOW;	/* we know he heard */
-	bcopy(cp+4, (char *)&w, sizeof(w));
+	memcpy(&w, cp+4, sizeof(w));
 	w.ws_row = ntohs(w.ws_row);
 	w.ws_col = ntohs(w.ws_col);
 	w.ws_xpixel = ntohs(w.ws_xpixel);
@@ -591,7 +665,7 @@ void protocol(int f, int master)
 						if (n) {
 							left -= n;
 							if (left > 0)
-								bcopy(cp+n, cp, left);
+								memmove(cp, cp+n, left);
 							fcc -= n;
 							goto top; /* n^2 */
 						}
@@ -687,7 +761,7 @@ void fatal(int f, const char *msg, int syserr)
 		*bp++ = '\01';		/* error indicator */
 	if (syserr)
 		sprintf(bp, "rlogind: %s: %s.\r\n",
-		    msg, k_strerror(errno));
+		    msg, strerror(errno));
 	else
 		sprintf(bp, "rlogind: %s.\r\n", msg);
 	len = strlen(bp);
@@ -702,24 +776,9 @@ void fatal(int f, const char *msg, int syserr)
 	exit(1);
 }
 
-int do_rlogin(struct sockaddr_in *dest)
-{
-	getstr(rusername, sizeof(rusername), "remuser too long");
-	getstr(lusername, sizeof(lusername), "locuser too long");
-	getstr(term+ENVSIZE, sizeof(term)-ENVSIZE, "Terminal type too long");
-
-	pwd = getpwnam(lusername);
-	if (pwd == NULL)
-		return (-1);
-	if (pwd->pw_uid == 0)
-	  {
-	  	syslog(LOG_ALERT, "NIS attack, user %s has uid 0", lusername);
-		return (-1);
-	  }
-	return (iruserok(dest->sin_addr.s_addr, 0, rusername, lusername));
-}
-
-void getstr(char *buf, int cnt, char *errmsg)
+static
+void
+xgetstr(char *buf, int cnt, char *errmsg)
 {
 	char c;
 
@@ -732,6 +791,24 @@ void getstr(char *buf, int cnt, char *errmsg)
 	} while (c != 0);
 }
 
+static int
+do_rlogin(struct sockaddr_in *dest)
+{
+	xgetstr(rusername, sizeof(rusername), "remuser too long");
+	xgetstr(lusername, sizeof(lusername), "locuser too long");
+	xgetstr(term+ENVSIZE, sizeof(term)-ENVSIZE, "Terminal type too long");
+
+	pwd = k_getpwnam(lusername);
+	if (pwd == NULL)
+		return (-1);
+	if (pwd->pw_uid == 0 && strcmp("root", lusername) != 0)
+	  {
+	  	syslog(LOG_ALERT, "NIS attack, user %s has uid 0", lusername);
+		return (-1);
+	  }
+	return (iruserok(dest->sin_addr.s_addr, 0, rusername, lusername));
+}
+
 extern	char **environ;
 
 void setup_term(int fd)
@@ -815,11 +892,11 @@ int do_krb_login(struct sockaddr_in *dest)
 	if (rc != KSUCCESS)
 		return (rc);
 
-	getstr(lusername, sizeof(lusername), "locuser");
+	xgetstr(lusername, sizeof(lusername), "locuser");
 	/* get the "cmd" in the rcmd protocol */
-	getstr(term+ENVSIZE, sizeof(term)-ENVSIZE, "Terminal type");
+	xgetstr(term+ENVSIZE, sizeof(term)-ENVSIZE, "Terminal type");
 
-	pwd = getpwnam(lusername);
+	pwd = k_getpwnam(lusername);
 	if (pwd == NULL)
 		return (-1);
 	if (pwd->pw_uid == 0 && strcmp("root", lusername) != 0)
