@@ -33,7 +33,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rsh.c,v 1.13 1996/04/08 11:54:01 bg Exp $");
+RCSID("$Id: rsh.c,v 1.17 1996/06/08 00:57:52 joda Exp $");
 
 CREDENTIALS cred;
 Key_schedule schedule;
@@ -78,7 +78,7 @@ copyargs(char **argv)
 	for (ap = argv; *ap; ++ap)
 		cc += strlen(*ap) + 1;
 	if (!(args = malloc((u_int)cc))) {
-		(void)fprintf(stderr, "rsh: %s.\n", k_strerror(ENOMEM));
+		(void)fprintf(stderr, "rsh: %s.\n", strerror(ENOMEM));
 		exit(1);
 	}
 	for (p = args, ap = argv; *ap; ++ap) {
@@ -93,7 +93,7 @@ copyargs(char **argv)
 static RETSIGTYPE
 sendsig(int signo_)
 {
-  unsigned char signo = signo_;
+    char signo = signo_;
 	if (doencrypt)
 #ifdef NOENCRYPTION
 		(void)write(rfd2, &signo, 1);
@@ -128,7 +128,7 @@ rewrite:	FD_ZERO(&rembits);
 		if (select(16, 0, &rembits, 0, 0) < 0) {
 			if (errno != EINTR) {
 				(void)fprintf(stderr,
-				    "rsh: select: %s.\n", k_strerror(errno));
+				    "rsh: select: %s.\n", strerror(errno));
 				exit(1);
 			}
 			goto rewrite;
@@ -168,7 +168,7 @@ done:
 		if (select(16, &ready, 0, 0, 0) < 0) {
 			if (errno != EINTR) {
 				(void)fprintf(stderr,
-				    "rsh: select: %s.\n", k_strerror(errno));
+				    "rsh: select: %s.\n", strerror(errno));
 				exit(1);
 			}
 			continue;
@@ -254,7 +254,7 @@ main(int argc, char **argv)
 		++p;
 	else
 		p = argv[0];
-	if (strcmp(p, "rsh"))
+	if (strcmp(p, "rsh") && strcmp(p, "remsh"))
 		host = p;
 	else
 		asrsh = 1;
@@ -343,12 +343,12 @@ try_connect:
 			rem = krcmd(&host, sv_port, user, args, &rfd2,
 			    dest_realm);
 		if (rem < 0) {
-			use_kerberos = 0;
-			sv_port=get_shell_port(use_kerberos, doencrypt);
 			if (errno == ECONNREFUSED)
 			  warning("remote host doesn't support Kerberos", "");
 			if (errno == ENOENT)
 			  warning("can't provide Kerberos auth data", "");
+			use_kerberos = 0;
+			sv_port=get_shell_port(use_kerberos, doencrypt);
 			goto try_connect;
 		}
 	} else {
@@ -371,11 +371,11 @@ try_connect:
 		if (setsockopt(rem, SOL_SOCKET, SO_DEBUG, (void *)&one,
 		    sizeof(one)) < 0)
 			(void)fprintf(stderr, "rsh: setsockopt: %s.\n",
-			    k_strerror(errno));
+			    strerror(errno));
 		if (setsockopt(rfd2, SOL_SOCKET, SO_DEBUG, (void *)&one,
 		    sizeof(one)) < 0)
 			(void)fprintf(stderr, "rsh: setsockopt: %s.\n",
-			    k_strerror(errno));
+			    strerror(errno));
 	}
 
 	(void)setuid(uid);
@@ -399,7 +399,7 @@ try_connect:
 		pid = fork();
 		if (pid < 0) {
 			(void)fprintf(stderr,
-			    "rsh: fork: %s.\n", k_strerror(errno));
+			    "rsh: fork: %s.\n", strerror(errno));
 			exit(1);
 		}
 	}
