@@ -42,7 +42,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rshd.c,v 1.25 1996/04/19 10:21:37 bg Exp $");
+RCSID("$Id: rshd.c,v 1.29 1996/05/29 23:23:26 assar Exp $");
 
 #include <sys/ioctl.h>
 
@@ -57,7 +57,6 @@ static int	sent_null;
 
 void	 doit __P((struct sockaddr_in *));
 void	 error __P((const char *, ...));
-void	 getstr __P((char *, int, char *));
 int	 local_domain __P((char *));
 char	*topdomain __P((char *));
 void	 usage __P((void));
@@ -153,7 +152,25 @@ char	shell[64] = "SHELL=";
 char	path[100] = "PATH=";
 char	*envinit[] =
 	    {homedir, shell, path, username, 0};
-char	**environ;
+
+static
+void
+xgetstr(buf, cnt, err)
+	char *buf, *err;
+	int cnt;
+{
+	char c;
+
+	do {
+		if (read(STDIN_FILENO, &c, 1) != 1)
+			exit(1);
+		*buf++ = c;
+		if (--cnt == 0) {
+			error("%s too long\n", err);
+			exit(1);
+		}
+	} while (c != 0);
+}
 
 void
 doit(fromp)
@@ -317,9 +334,10 @@ doit(fromp)
 					hostname = inet_ntoa(fromp->sin_addr);
 					break;
 				}
-				if (!bcmp(hp->h_addr_list[0],
-				    (caddr_t)&fromp->sin_addr,
-				    sizeof(fromp->sin_addr))) {
+				if (memcmp(hp->h_addr_list[0],
+					   &fromp->sin_addr,
+					   sizeof(fromp->sin_addr)) ==
+				    0) {
 					hostname = hp->h_name;
 					break;
 				}
@@ -351,7 +369,7 @@ doit(fromp)
 #ifndef NOENCRYPTION
 			des_set_key(&kdata->session, schedule);
 #else
-			bzero(schedule, sizeof(schedule));
+			memset(schedule, 0, sizeof(schedule));
 #endif
 		} else
 			rc = krb_recvauth(authopts, 0, ticket, "rcmd",
@@ -364,12 +382,12 @@ doit(fromp)
 			exit(1);
 		}
 	} else
-		getstr(remuser, sizeof(remuser), "remuser");
+		xgetstr(remuser, sizeof(remuser), "remuser");
 
-	getstr(locuser, sizeof(locuser), "locuser");
-	getstr(cmdbuf, sizeof(cmdbuf), "command");
+	xgetstr(locuser, sizeof(locuser), "locuser");
+	xgetstr(cmdbuf, sizeof(cmdbuf), "command");
 	setpwent();
-	pwd = getpwnam(locuser);
+	pwd = k_getpwnam(locuser);
 	if (pwd == NULL) {
 		syslog(LOG_INFO|LOG_AUTH,
 		    "%s@%s as %s: unknown login. cmd='%.80s'",
@@ -604,9 +622,6 @@ fail:
 	(void) setgid((gid_t)pwd->pw_gid);
 	initgroups(pwd->pw_name, pwd->pw_gid);
 	(void) setuid((uid_t)pwd->pw_uid);
-#if 0
-	environ = envinit;
-#endif
 	strncat(homedir, pwd->pw_dir, sizeof(homedir)-6);
 
 	/* Need to extend path to find rcp */
@@ -663,24 +678,6 @@ error(const char *fmt, ...)
 	(void)write(STDERR_FILENO, buf, len + strlen(bp));
 }
 
-void
-getstr(buf, cnt, err)
-	char *buf, *err;
-	int cnt;
-{
-	char c;
-
-	do {
-		if (read(STDIN_FILENO, &c, 1) != 1)
-			exit(1);
-		*buf++ = c;
-		if (--cnt == 0) {
-			error("%s too long\n", err);
-			exit(1);
-		}
-	} while (c != 0);
-}
-
 /*
  * Check whether host h is in our local domain,
  * defined as sharing the last two components of the domain part,
