@@ -33,7 +33,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: su.c,v 1.42 1996/04/24 09:19:16 bg Exp $");
+RCSID("$Id: su.c,v 1.45 1996/05/31 08:34:24 bg Exp $");
 
 #ifdef SYSV_SHADOW
 #include "sysv_shadow.h"
@@ -65,7 +65,7 @@ main(argc, argv)
 	uid_t ruid;
 	int asme, ch, asthem, fastlogin, prio;
 	enum { UNSET, YES, NO } iscsh = UNSET;
-	char *user, *shell, *avshell, *username, *cleanenv[10], **np;
+	char *user, *shell, *avshell, *username, **np;
 	char shellbuf[MaxPathLen], avshellbuf[MaxPathLen];
 
 	asme = asthem = fastlogin = 0;
@@ -120,7 +120,7 @@ main(argc, argv)
 	/* get current login name and shell */
 	ruid = getuid();
 	username = getlogin();
-	if (username == NULL || (pwd = getpwnam(username)) == NULL ||
+	if (username == NULL || (pwd = k_getpwnam(username)) == NULL ||
 	    pwd->pw_uid != ruid)
 		pwd = getpwuid(ruid);
 	if (pwd == NULL) {
@@ -140,7 +140,7 @@ main(argc, argv)
 	user = *argv ? *argv : "root";
 	np = *argv ? argv : argv-1;
 
-	pwd = getpwnam(user);
+	pwd = k_getpwnam(user);
 	if (pwd == NULL){
 		fprintf(stderr, "su: unknown login %s\n", user);
 		exit(1);
@@ -158,7 +158,7 @@ main(argc, argv)
 	  exit(1);
 #endif
 	  /* getpwnam() is not reentrant and kerberos might use it! */
-	  pwd = getpwnam(user);
+	  pwd = k_getpwnam(user);
 	  if (pwd == NULL){
 		  fprintf(stderr, "su: unknown login %s\n", user);
 		  exit(1);
@@ -239,14 +239,14 @@ main(argc, argv)
 
 	if (!asme) {
 		if (asthem) {
-		  char *k=getenv("KRBTKFILE");
+		  char *k = getenv("KRBTKFILE");
 		  char *t = getenv("TERM");
-		  cleanenv[0] = NULL;
-		  environ = cleanenv;
+		  environ = malloc(10*sizeof(char *));
+		  environ[0] = NULL;
 		  setenv("PATH", _PATH_DEFPATH, 1);
-		  if(t)
+		  if (t)
 		    setenv("TERM", t, 1);
-		  if(k)
+		  if (k)
 		    setenv("KRBTKFILE", k, 1);
 		  if (chdir(pwd->pw_dir) < 0) {
 		    fprintf(stderr, "su: no directory\n");
@@ -372,7 +372,7 @@ kerberos(char *username, char *user, int uid)
 	  kerno = krb_get_pw_in_tkt((uid == 0 ? username : user),
 				    (uid == 0 ? root_inst : ""), lrealm,
 				    "krbtgt", lrealm, DEFAULT_TKT_LIFE, passw);
-	  bzero(passw, strlen(passw));
+	  memset(passw, 0, strlen(passw));
 	}
 
 	if (kerno != KSUCCESS) {
@@ -438,7 +438,7 @@ kerberos(char *username, char *user, int uid)
 			dest_tkt();
 			return (1);
 		}
-		(void)bcopy((char *)hp->h_addr, (char *)&faddr, sizeof(faddr));
+		(void)memcpy((char *)&faddr, (char *)hp->h_addr, sizeof(faddr));
 
 		if ((kerno = krb_rd_req(&ticket, "rcmd", savehost, faddr,
 		    &authdata, "")) != KSUCCESS) {
@@ -463,7 +463,7 @@ koktologin(char *name, char *realm, char *toname)
 	AUTH_DAT kdata_st;
 
 	kdata = &kdata_st;
-	bzero((caddr_t) kdata, sizeof(*kdata));
+	memset(kdata, 0, sizeof(*kdata));
 	(void)strcpy(kdata->pname, name);
 	(void)strcpy(kdata->pinst,
 	    ((strcmp(toname, "root") == 0) ? root_inst : ""));
