@@ -1,6 +1,6 @@
 #include "bsd_locl.h"
 
-RCSID("$Id: utmp_login.c,v 1.2 1996/03/28 11:10:37 bg Exp $");
+RCSID("$Id: utmp_login.c,v 1.3 1996/06/07 22:37:37 joda Exp $");
 
 /* update utmp and wtmp - the BSD way */
 
@@ -12,6 +12,7 @@ void utmp_login(char *tty, char *username, char *hostname)
     int fd;
 
     char *ttyx; /* tty w/o /dev/* */
+    char *id;
 
     ttyx = tty;
 
@@ -49,7 +50,10 @@ void utmp_login(char *tty, char *username, char *hostname)
 
 # ifdef HAVE_UT_ID
     /* any particular reason to not include "tty" ? */
-    strncpy(utmp.ut_id, ttyx, sizeof(utmp.ut_id));
+    id = ttyx;
+    if(strncmp(ttyx, "tty", 3) == 0)
+	id += 3;
+    strncpy(utmp.ut_id, id, sizeof(utmp.ut_id));
 # endif
 
 
