@@ -35,6 +35,10 @@
 
 #include "ftp_locl.h"
 
+#ifndef INADDR_NONE
+#define INADDR_NONE 0xffffffff
+#endif
+
 struct	sockaddr_in hisctladdr;
 struct	sockaddr_in data_addr;
 int	data = -1;
@@ -58,7 +62,8 @@ hookup(char *host, int port)
 	static char hostnamebuf[80];
 
 	memset((char *)&hisctladdr, 0, sizeof (hisctladdr));
-	if (inet_aton(host, &hisctladdr.sin_addr) != 0) {
+	hisctladdr.sin_addr.s_addr = inet_addr(host);
+	if (hisctladdr.sin_addr.s_addr != INADDR_NONE) {
 		hisctladdr.sin_family = AF_INET;
 		(void) strncpy(hostnamebuf, host, sizeof(hostnamebuf));
 	} else {
@@ -161,45 +166,59 @@ int
 login(char *host)
 {
 	char tmp[80];
+	char defaultpass[128];
 	char *user, *pass, *acct;
 	int n, aflag = 0;
 
+	char *myname = NULL;
+	struct passwd *pw = getpwuid(getuid());
+	if (pw != NULL)
+	    myname = pw->pw_name;
+
 	user = pass = acct = 0;
+	
 
 	if(do_klogin(host))
 	    printf("\n*** Using plaintext user and password ***\n\n");
-	else
+	else{
 	    printf("Kerberos login successful.\n\n");
+	}
 
 	if (ruserpass(host, &user, &pass, &acct) < 0) {
 		code = -1;
 		return (0);
 	}
 	while (user == NULL) {
-		char *myname = NULL;
-		struct passwd *pp = getpwuid(getuid());
-
-		if (pp != NULL)
-		        myname = pp->pw_name;
-		if (myname)
-			printf("Name (%s:%s): ", host, myname);
-		else
-			printf("Name (%s): ", host);
-		(void) fgets(tmp, sizeof(tmp) - 1, stdin);
-		tmp[strlen(tmp) - 1] = '\0';
-		if (*tmp == '\0')
-			user = myname;
-		else
-			user = tmp;
+	    if (myname)
+		printf("Name (%s:%s): ", host, myname);
+	    else
+		printf("Name (%s): ", host);
+	    fgets(tmp, sizeof(tmp) - 1, stdin);
+	    tmp[strlen(tmp) - 1] = '\0';
+	    if (*tmp == '\0')
+		user = myname;
+	    else
+		user = tmp;
 	}
 	strcpy(username, user);
 	n = command("USER %s", user);
 	if (n == CONTINUE) {
 	    if(auth_complete)
-		pass = user;
+		pass = myname;
 	    else if (pass == NULL) {
-	        des_read_pw_string (tmp, sizeof(tmp), "Password:", 0);
-		pass = tmp;
+		char prompt[128];
+		if(myname && 
+		   (!strcmp(user, "ftp") || !strcmp(user, "anonymous"))){
+		    sprintf(defaultpass, "%s@%s", myname, mydomain+1);
+		    sprintf(prompt, "Password (%s): ", defaultpass);
+		}else{
+		    strcpy(defaultpass, "");
+		    sprintf(prompt, "Password: ");
+		}
+		pass = defaultpass;
+	        des_read_pw_string (tmp, sizeof(tmp), prompt, 0);
+		if(tmp[0])
+		    pass = tmp;
 	    }
 	    n = command("PASS %s", pass);
 	}
@@ -224,6 +243,7 @@ login(char *host)
 			break;
 		}
 	}
+	sec_set_protection_level();
 	return (1);
 }
 
@@ -511,6 +531,49 @@ abortsend(int sig)
 
 #define HASHBYTES 1024
 
+
+static int
+copy_stream(FILE *from, FILE *to)
+{
+    char buf[BUFSIZ];
+    int n;
+    int bytes = 0;
+    struct stat st;
+
+    int werr;
+    
+    void *chunk;
+
+#ifdef HAVE_MMAP
+    if(fstat(fileno(from), &st) == 0 && S_ISREG(st.st_mode)){
+	chunk = mmap(0, st.st_size, PROT_READ, MAP_SHARED, fileno(from), 0);
+	if(chunk != NULL){
+	    sec_write(fileno(to), chunk, st.st_size);
+	    munmap(chunk, st.st_size);
+	    sec_fflush(to);
+	    return st.st_size;
+	}
+    }
+#endif
+
+    while((n = read(fileno(from), buf, sizeof(buf))) > 0){
+	werr = sec_write(fileno(to), buf, n);
+	if(werr < 0)
+	    break;
+	bytes += werr;
+    }
+    sec_fflush(to);
+    if(n < 0)
+	warn("local");
+
+    if(werr < 0){
+	if(errno != EPIPE)
+	    warn("netout");
+	bytes = -1;
+    }
+    return bytes;
+}
+
 void
 sendrequest(char *cmd, char *local, char *remote, int printnames)
 {
@@ -655,34 +718,8 @@ sendrequest(char *cmd, char *local, char *remote, int printnames)
 
 	case TYPE_I:
 	case TYPE_L:
-		errno = d = 0;
-		while ((c = read(fileno(fin), buf, sizeof (buf))) > 0) {
-			bytes += c;
-			for (bufp = buf; c > 0; c -= d, bufp += d)
-			    if ((d = sec_write(fileno(dout), bufp, c)) <= 0)
-				break;
-			if (hash) {
-				while (bytes >= hashbytes) {
-					(void) putchar('#');
-					hashbytes += HASHBYTES;
-				}
-				(void) fflush(stdout);
-			}
-		}
-		sec_fflush(dout);
-		if (hash && bytes > 0) {
-			if (bytes < HASHBYTES)
-				(void) putchar('#');
-			(void) putchar('\n');
-			(void) fflush(stdout);
-		}
-		if (c < 0)
-			warn("local: %s", local);
-		if (d < 0) {
-			if (errno != EPIPE) 
-				warn("netout");
-			bytes = -1;
-		}
+		errno = d = c = 0;
+		bytes = copy_stream(fin, dout);
 		break;
 
 	case TYPE_A:
@@ -1073,6 +1110,9 @@ initconn(void)
 	int a0, a1, a2, a3, p0, p1;
 
 	if (passivemode) {
+	        u_int32_t tmpaddr;
+		u_int16_t tmpport;
+
 		data = socket(AF_INET, SOCK_STREAM, 0);
 		if (data < 0) {
 			perror("ftp: socket");
@@ -1104,12 +1144,14 @@ initconn(void)
 
 		memset(&data_addr, 0, sizeof(data_addr));
 		data_addr.sin_family = AF_INET;
-		a = (char *)&data_addr.sin_addr.s_addr;
+		tmpaddr = data_addr.sin_addr.s_addr;
+		a = (char *)&tmpaddr;
 		a[0] = a0 & 0xff;
 		a[1] = a1 & 0xff;
 		a[2] = a2 & 0xff;
 		a[3] = a3 & 0xff;
-		p = (char *)&data_addr.sin_port;
+		tmpport = data_addr.sin_port;
+		p = (char *)&tmpport;
 		p[0] = p0 & 0xff;
 		p[1] = p1 & 0xff;
 
@@ -1160,19 +1202,21 @@ noport:
 	if (listen(data, 1) < 0)
 		warn("listen");
 	if (sendport) {
-		a = (char *)&data_addr.sin_addr;
-		p = (char *)&data_addr.sin_port;
-#define	UC(b)	(((int)b)&0xff)
-		result =
-		    command("PORT %d,%d,%d,%d,%d,%d",
-		      UC(a[0]), UC(a[1]), UC(a[2]), UC(a[3]),
-		      UC(p[0]), UC(p[1]));
-		if (result == ERROR && sendport == -1) {
-			sendport = 0;
-			tmpno = 1;
-			goto noport;
-		}
-		return (result != COMPLETE);
+	    unsigned int a = ntohl(data_addr.sin_addr.s_addr);
+	    unsigned int p = ntohs(data_addr.sin_port);
+	    result = command("PORT %d,%d,%d,%d,%d,%d", 
+			     (a >> 24) & 0xff,
+			     (a >> 16) & 0xff,
+			     (a >> 8) & 0xff,
+			     a & 0xff,
+			     (p >> 8) & 0xff,
+			     p & 0xff);
+	    if (result == ERROR && sendport == -1) {
+		sendport = 0;
+		tmpno = 1;
+		goto noport;
+	    }
+	    return (result != COMPLETE);
 	}
 	if (tmpno)
 		sendport = 1;
@@ -1249,7 +1293,7 @@ pswitch(int flag)
 	sighand oldintr;
 	static struct comvars {
 		int connect;
-		char name[MAXHOSTNAMELEN];
+		char name[MaxHostNameLen];
 		struct sockaddr_in mctl;
 		struct sockaddr_in hctl;
 		FILE *in;
@@ -1264,8 +1308,8 @@ pswitch(int flag)
 		char nti[17];
 		char nto[17];
 		int mapflg;
-		char mi[MAXPATHLEN];
-		char mo[MAXPATHLEN];
+		char mi[MaxPathLen];
+		char mo[MaxPathLen];
 	} proxstruct, tmpstruct;
 	struct comvars *ip, *op;
 
@@ -1322,10 +1366,10 @@ pswitch(int flag)
 	(void) strcpy(ntout, op->nto);
 	ip->mapflg = mapflag;
 	mapflag = op->mapflg;
-	(void) strncpy(ip->mi, mapin, MAXPATHLEN - 1);
+	(void) strncpy(ip->mi, mapin, MaxPathLen - 1);
 	(ip->mi)[strlen(ip->mi)] = '\0';
 	(void) strcpy(mapin, op->mi);
-	(void) strncpy(ip->mo, mapout, MAXPATHLEN - 1);
+	(void) strncpy(ip->mo, mapout, MaxPathLen - 1);
 	(ip->mo)[strlen(ip->mo)] = '\0';
 	(void) strcpy(mapout, op->mo);
 	(void) signal(SIGINT, oldintr);
@@ -1488,7 +1532,7 @@ reset(int argc, char **argv)
 char *
 gunique(char *local)
 {
-	static char new[MAXPATHLEN];
+	static char new[MaxPathLen];
 	char *cp = strrchr(local, '/');
 	int d, count=0;
 	char ext = '1';
