@@ -5,6 +5,9 @@
 #include <config.h>
 #endif
 
+#include <sys/bitypes.h>
+#include <sys/cdefs.h>
+
 #include <pwd.h>
 #include <signal.h>
 #include <stdio.h>
@@ -37,6 +40,10 @@
 #include <glob.h>
 #include <netdb.h>
 
+#ifdef HAVE_SYS_MMAN_H
+#include <sys/mman.h>
+#endif
+
 extern int h_errno;
 
 #include "extern.h"
