@@ -35,7 +35,7 @@
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-RCSID("$Id: ftpd.c,v 1.18 1996/05/06 11:14:02 bg Exp $");
+RCSID("$Id: ftpd.c,v 1.26 1996/06/16 02:26:19 joda Exp $");
 #endif
 
 /*
@@ -89,7 +89,9 @@ RCSID("$Id: ftpd.c,v 1.18 1996/05/06 11:14:02 bg Exp $");
 #include <kafs.h>
 #include "roken.h"
 
-#undef SKEY
+#if defined(SKEY)
+#include <skey.h>
+#endif
 
 void yyparse();
 
@@ -100,6 +102,10 @@ extern int optind, opterr;
 #define LOG_FTP LOG_DAEMON
 #endif
 
+#ifndef LOG_DAEMON
+#define openlog(id,option,facility) openlog((id),(option))
+#endif
+
 static char version[] = "Version 6.00";
 
 extern	off_t restart_point;
@@ -137,8 +143,8 @@ off_t	byte_count;
 #endif
 int	defumask = CMASK;		/* default umask value */
 char	tmpline[10240];
-char	hostname[MAXHOSTNAMELEN];
-char	remotehost[MAXHOSTNAMELEN];
+char	hostname[MaxHostNameLen];
+char	remotehost[MaxHostNameLen];
 static char ttyline[20];
 char	*tty = ttyline;		/* for klogin */
 
@@ -201,12 +207,12 @@ static char	*gunique (char *);
 static void	 lostconn (int);
 static int	 receive_data (FILE *, FILE *);
 static void	 send_data (FILE *, FILE *, off_t);
-static struct passwd * sgetpwnam (char *);
+static struct passwd * sk_getpwnam (char *);
 
 static char *
 curdir(void)
 {
-	static char path[MAXPATHLEN+1+1];	/* path + '/' + '\0' */
+	static char path[MaxPathLen+1+1];	/* path + '/' + '\0' */
 
 	if (getcwd(path, sizeof(path)-2) == NULL)
 		return ("");
@@ -464,7 +470,7 @@ sgetpwnam(char *name)
 	static struct passwd save;
 	struct passwd *p;
 
-	if ((p = getpwnam(name)) == NULL)
+	if ((p = k_getpwnam(name)) == NULL)
 		return (p);
 	if (save.pw_name) {
 		free(save.pw_name);
@@ -485,6 +491,10 @@ sgetpwnam(char *name)
 static int login_attempts;	/* number of failed login attempts */
 static int askpasswd;		/* had user command, ask for passwd */
 static char curname[10];	/* current USER name */
+#ifdef SKEY
+static struct skey sk;
+static int permit_passwd;
+#endif /* SKEY */
 
 /*
  * USER command.
@@ -558,21 +568,26 @@ user(char *name)
 	}
 	if (logging)
 		strncpy(curname, name, sizeof(curname)-1);
+	if(auth_ok())
+		ct->userok(name);
+	else {
 #ifdef SKEY
-	if (!skey_haskey(name)) {
-		char *myskey, *skey_keyinfo (char *name);
+		char ss[256];
 
-		myskey = skey_keyinfo(name);
-		reply(331, "Password [%s] for %s required.",
-		    myskey ? myskey : "error getting challenge", name);
-	} else
+		permit_passwd = skeyaccess(k_getpwnam (name), NULL,
+					   remotehost, NULL);
+
+		if (skeychallenge (&sk, name, ss) == 0) {
+			reply (331, "Password [%s] for %s required.",
+			       ss, name);
+			askpasswd = 1;
+		} else if (permit_passwd)
 #endif
-	     if(auth_ok())
-		  ct->userok(name);
-	     else{
-		  reply(331, "Password required for %s.", name);
-		  askpasswd = 1;
-	     }
+		{
+			reply(331, "Password required for %s.", name);
+			askpasswd = 1;
+		}
+	}
 	/*
 	 * Delay before reading passwd after first failed
 	 * attempt to slow down passwd-guessing programs.
@@ -665,8 +680,7 @@ int do_login(int code, char *passwd)
 	if (guest) {
 		reply(code, "Guest login ok, access restrictions apply.");
 #ifdef HAVE_SETPROCTITLE
-		snprintf(proctitle, sizeof(proctitle),
-		    "%s: anonymous/%.*s", remotehost,
+		sprintf(proctitle, "%s: anonymous/%.*s", remotehost,
 		    sizeof(proctitle) - sizeof(remotehost) -
 		    sizeof(": anonymous/"), passwd);
 		setproctitle(proctitle);
@@ -677,8 +691,7 @@ int do_login(int code, char *passwd)
 	} else {
 		reply(code, "User %s logged in.", pw->pw_name);
 #ifdef HAVE_SETPROCTITLE
-		snprintf(proctitle, sizeof(proctitle),
-		    "%s: %s", remotehost, pw->pw_name);
+		sprintf(proctitle, "%s: %s", remotehost, pw->pw_name);
 		setproctitle(proctitle);
 #endif /* HAVE_SETPROCTITLE */
 		if (logging)
@@ -727,16 +740,19 @@ pass(char *passwd)
 			rval = 1;	/* failure below */
 			goto skip;
 		}
-		rval = klogin(pw->pw_name, passwd);
-		if (rval == 0)
-		    goto skip;
 #ifdef SKEY
-		if (skey_haskey(pw->pw_name) == 0 &&
-		   (skey_passcheck(pw->pw_name, passwd) != -1)) {
+		if (skeyverify (&sk, passwd) == 0) {
 			rval = 0;
 			goto skip;
+		} else if(!permit_passwd) {
+			rval = 1;
+			goto skip;
 		}
 #endif
+		rval = klogin(pw->pw_name, passwd);
+		if (rval == 0)
+			goto skip;
+
 		/* the strcmp does not catch null passwords! */
 		if (pw == NULL || *pw->pw_passwd == 0 ||
 		    strcmp((char*)crypt(passwd, pw->pw_passwd), pw->pw_passwd)){
@@ -1173,7 +1189,8 @@ receive_data(FILE *instr, FILE *outstr)
     {
 	char *p, *q;
 	int cr_flag = 0;
-	while ((cnt = auth_read(fileno(instr), buf+cr_flag, sizeof(buf))) > 0){
+	while ((cnt = auth_read(fileno(instr), buf+cr_flag, 
+				sizeof(buf)-cr_flag)) > 0){
 	    byte_count += cnt;
 	    cr_flag = 0;
 	    for(p = buf, q = buf; p < buf + cnt;){
@@ -1234,7 +1251,7 @@ statfilecmd(char *filename)
 	int c;
 	char line[LINE_MAX];
 
-	(void)snprintf(line, sizeof(line), "/bin/ls -lA %s", filename);
+	sprintf(line, "/bin/ls -lA %s", filename);
 	fin = ftpd_popen(line, "r");
 	lreply(211, "status of %s:", filename);
 	while ((c = getc(fin)) != EOF) {
@@ -1447,7 +1464,7 @@ removedir(char *name)
 void
 pwd(void)
 {
-    char path[MAXPATHLEN + 1];
+    char path[MaxPathLen + 1];
     char *ret;
 
     /* SunOS has a broken getcwd that does popen(pwd) (!!!), this
@@ -1498,7 +1515,7 @@ dolog(struct sockaddr_in *sin)
 		(void) strncpy(remotehost, inet_ntoa(sin->sin_addr),
 		    sizeof(remotehost));
 #ifdef HAVE_SETPROCTITLE
-	snprintf(proctitle, sizeof(proctitle), "%s: connected", remotehost);
+	sprintf(proctitle, "%s: connected", remotehost);
 	setproctitle(proctitle);
 #endif /* HAVE_SETPROCTITLE */
 
@@ -1522,7 +1539,11 @@ dologout(int status)
 		    k_unlog();
 	}
 	/* beware of flushing buffers after a SIGPIPE */
+#ifdef XXX
+	exit(status);
+#else
 	_exit(status);
+#endif	
 }
 
 void abor(void)
@@ -1624,7 +1645,7 @@ pasv_error:
 static char *
 gunique(char *local)
 {
-	static char new[MAXPATHLEN];
+	static char new[MaxPathLen];
 	struct stat st;
 	int count;
 	char *cp;
@@ -1677,6 +1698,8 @@ send_file_list(char *whichf)
 	int freeglob = 0;
 	glob_t gl;
 
+	char buf[MaxPathLen];
+
 	if (strpbrk(whichf, "~{[*?") != NULL) {
 		int flags = GLOB_BRACE|GLOB_NOCHECK|GLOB_QUOTE|GLOB_TILDE;
 
@@ -1729,8 +1752,9 @@ send_file_list(char *whichf)
 					goto out;
 				transflag++;
 			}
-			fprintf(dout, "%s%s\n", dirname,
+			sprintf(buf, "%s%s\n", dirname,
 				type == TYPE_A ? "\r" : "");
+			auth_write(fileno(dout), buf, strlen(buf));
 			byte_count += strlen(dirname) + 1;
 			continue;
 		} else if (!S_ISDIR(st.st_mode))
@@ -1740,7 +1764,7 @@ send_file_list(char *whichf)
 			continue;
 
 		while ((dir = readdir(dirp)) != NULL) {
-			char nbuf[MAXPATHLEN];
+			char nbuf[MaxPathLen];
 
 			if (!strcmp(dir->d_name, "."))
 				continue;
@@ -1754,26 +1778,25 @@ send_file_list(char *whichf)
 			 * not a directory or special file.
 			 */
 			if (simple || (stat(nbuf, &st) == 0 &&
-			    S_ISREG(st.st_mode))) {
-				if (dout == NULL) {
-					dout = dataconn("file list", (off_t)-1,
-						"w");
-					if (dout == NULL)
-						goto out;
-					transflag++;
-				}
-				if (nbuf[0] == '.' && nbuf[1] == '/')
-					fprintf(dout, "%s%s\n", &nbuf[2],
-						type == TYPE_A ? "\r" : "");
-				else
-					fprintf(dout, "%s%s\n", nbuf,
-						type == TYPE_A ? "\r" : "");
-				byte_count += strlen(nbuf) + 1;
+				       S_ISREG(st.st_mode))) {
+			    if (dout == NULL) {
+				dout = dataconn("file list", (off_t)-1, "w");
+				if (dout == NULL)
+				    goto out;
+				transflag++;
+			    }
+			    if(strncmp(nbuf, "./", 2) == 0)
+				sprintf(buf, "%s%s\n", nbuf +2,
+					type == TYPE_A ? "\r" : "");
+			    else
+				sprintf(buf, "%s%s\n", nbuf,
+					type == TYPE_A ? "\r" : "");
+			    auth_write(fileno(dout), buf, strlen(buf));
+			    byte_count += strlen(nbuf) + 1;
 			}
 		}
 		(void) closedir(dirp);
 	}
-
 	if (dout == NULL)
 		reply(550, "No files found.");
 	else if (ferror(dout) != 0)
@@ -1782,8 +1805,11 @@ send_file_list(char *whichf)
 		reply(226, "Transfer complete.");
 
 	transflag = 0;
-	if (dout != NULL)
-		(void) fclose(dout);
+	if (dout != NULL){
+	    auth_write(fileno(dout), buf, 0); /* XXX flush */
+	    
+	    (void) fclose(dout);
+	}
 	data = -1;
 	pdata = -1;
 out:
