@@ -8,7 +8,7 @@
 
 #include "kauth.h"
 
-RCSID("$Id: kauth.c,v 1.55 1996/04/25 19:16:32 d91-jda Exp $");
+RCSID("$Id: kauth.c,v 1.58 1996/06/14 09:45:37 assar Exp $");
 
 char *prog;
 static char inst[100];
@@ -47,7 +47,7 @@ doexec(argc, argv)
     /* in child */
     execvp(argv[0], argv);
     fprintf(stderr, "%s: Can't exec program ``%s'' %s\n",
-	    prog, argv[0], k_strerror(errno));
+	    prog, argv[0], strerror(errno));
     exit(1);
     break;
   default:
@@ -206,39 +206,12 @@ main(argc, argv)
       upcase(realm);
     }
 
-  /* No kerberos name, look for old ticket file. */
-  if (name[0] == 0 && tf_init(file, R_TKT_FIL) == KSUCCESS)
+  if (name[0] == '\0' &&
+      krb_get_default_principal (name, inst, realm) < 0)
     {
-      (void) tf_close();
-      if ((code = krb_get_tf_realm(file, realm)) == KSUCCESS &&
-	  (code = tf_init(file, R_TKT_FIL)) == KSUCCESS &&
-	  (code = tf_get_pname(name)) == KSUCCESS &&
-	  (code = tf_get_pinst(inst)) == KSUCCESS)
-	(void) tf_close();	/* alles gut */
-      else
-	{
-	  fprintf(stderr,
-		  "failed to read %s: %s. Ignoring %s and continuing\n",
-		  file, krb_get_err_text(code), file);
-	  name[0] = 0;
-	}
-    }
-  /* Still no kerberos name, try username instead. */
-  if (name[0] == 0)
-    {
-      struct passwd *pw = getpwuid(getuid());
-      if (pw == 0)
-	{
-	  fprintf(stderr, "name must be non null\n");
-	  usage();
-	}
-      else
-	strncpy(name, pw->pw_name, sizeof(name));
-      if (strcmp(name, "root") == 0) /* Running as root? */
-	{
-	  strcpy(inst, name);
-	  strcpy(name, getenv("USER"));
-	}
+      fprintf (stderr, "%s: Could not get default principal\n",
+	       argv[0]);
+      return 1;
     }
   
   if (*remoteuser == '\0')
@@ -254,7 +227,7 @@ main(argc, argv)
     int f;
 
     do{
-      sprintf(tf, "/tmp/tkt%d_%d", (int)getuid(), (int)(getpid()*time(0)));
+      sprintf(tf, TKT_ROOT "%d_%d", (int)getuid(), (int)(getpid()*time(0)));
       f = open(tf, O_CREAT|O_EXCL|O_RDWR);
     }while(f < 0);
     close(f);
