@@ -1,6 +1,6 @@
 #include "kauth.h"
 
-RCSID("$Id: kauthd.c,v 1.4 1996/03/25 13:11:16 bg Exp $");
+RCSID("$Id: kauthd.c,v 1.5 1996/05/10 22:25:29 assar Exp $");
 
 static char name[SNAME_SZ + 1];
 static char inst[INST_SZ + 1];
@@ -95,7 +95,7 @@ doit(int sock)
 			   &auth.session, &thisaddr, &thataddr);
 	  return 1;
      }
-     passwd = getpwnam (locuser);
+     passwd = k_getpwnam (locuser);
      if (passwd == NULL) {
 	  sprintf (buf, "No user '%s'", locuser);
 	  write_encrypted (sock, buf, strlen(buf), schedule,
