@@ -1,6 +1,6 @@
 #include "kauth.h"
 
-RCSID("$Id: rkinit.c,v 1.6 1996/04/06 21:09:51 assar Exp $");
+RCSID("$Id: rkinit.c,v 1.7 1996/05/12 18:45:43 joda Exp $");
 
 extern char *prog;
 
@@ -71,14 +71,14 @@ doit_host (char *name, char *inst, char *realm, int lifetime,
      if (getsockname (s, (struct sockaddr *)&thisaddr, &addrlen) < 0 ||
 	 addrlen != sizeof(thisaddr)) {
 	  fprintf (stderr, "%s: getsockname(%s) failed: %s\n",
-		   prog, hostname, k_strerror(errno));
+		   prog, hostname, strerror(errno));
 	  return 1;
      }
      addrlen = sizeof(thataddr);
      if (getpeername (s, (struct sockaddr *)&thataddr, &addrlen) < 0 ||
 	 addrlen != sizeof(thataddr)) {
 	  fprintf (stderr, "%s: getpeername(%s) failed: %s\n",
-		   prog, hostname, k_strerror(errno));
+		   prog, hostname, strerror(errno));
 	  return 1;
      }
 
@@ -96,7 +96,7 @@ doit_host (char *name, char *inst, char *realm, int lifetime,
      if (write_encrypted(s, buf, inlen, schedule, &cred.session,
 			 &thisaddr, &thataddr) < 0) {
 	  fprintf (stderr, "%s: write to %s failed: %s\n",
-		   prog, hostname, k_strerror(errno));
+		   prog, hostname, strerror(errno));
 	  return 1;
      }
 
@@ -104,7 +104,7 @@ doit_host (char *name, char *inst, char *realm, int lifetime,
 			     &cred.session, &thataddr, &thisaddr);
      if (inlen < 0) {
 	  fprintf (stderr, "%s: read from %s failed: %s\n",
-		   prog, hostname, k_strerror(errno));
+		   prog, hostname, strerror(errno));
 	  return 1;
      }
 
@@ -131,7 +131,7 @@ doit_host (char *name, char *inst, char *realm, int lifetime,
 			     &cred.session, &thataddr, &thisaddr);
      if (inlen < 0) {
 	  fprintf (stderr, "%s: read from %s failed: %s\n",
-		   prog, hostname, k_strerror(errno));
+		   prog, hostname, strerror(errno));
 	  return 1;
      }
 
