@@ -51,9 +51,11 @@
  * or implied warranty.
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
-RCSID("$Id: kerberos.c,v 1.8 1996/03/11 09:21:51 bg Exp $");
+RCSID("$Id: kerberos.c,v 1.10 1996/05/05 04:39:40 assar Exp $");
 
 #ifdef	KRB4
 #include <sys/types.h>
@@ -75,14 +77,6 @@ RCSID("$Id: kerberos.c,v 1.8 1996/03/11 09:21:51 bg Exp $");
 #include "misc.h"
 
 int kerberos4_cksum P((unsigned char *, int));
-#ifndef KRB_DEFS
-int krb_mk_req P((KTEXT, char *, char *, char *, u_long));
-int krb_rd_req P((KTEXT, char *, char *, u_long, AUTH_DAT *, char *));
-int krb_kntoln P((AUTH_DAT *, char *));
-int krb_get_cred P((char *, char *, char *, CREDENTIALS *));
-int krb_get_lrealm P((char *, int));
-int kuserok P((AUTH_DAT *, char *));
-#endif
 extern auth_debug_mode;
 
 static unsigned char str_data[1024] = { IAC, SB, TELOPT_AUTHENTICATION, 0,
