@@ -33,7 +33,7 @@
 
 #include <config.h>
 
-RCSID("$Id: commands.c,v 1.9 1996/03/24 06:57:24 assar Exp $");
+RCSID("$Id: commands.c,v 1.12 1996/05/13 02:02:12 joda Exp $");
 
 #include <sys/param.h>
 #include <sys/types.h>
@@ -61,6 +61,8 @@ RCSID("$Id: commands.c,v 1.9 1996/03/24 06:57:24 assar Exp $");
 #include "defines.h"
 #include "types.h"
 
+#include "roken.h"
+
 #if !defined(CRAY) && !defined(sysV88)
 #include <netinet/in_systm.h>
 # if (defined(vax) || defined(tahoe) || defined(hp300)) && !defined(ultrix)
@@ -70,8 +72,8 @@ RCSID("$Id: commands.c,v 1.9 1996/03/24 06:57:24 assar Exp $");
 #include <netinet/ip.h>
 
 
-#ifndef	MAXHOSTNAMELEN
-#define	MAXHOSTNAMELEN 64
+#ifndef	MaxHostNameLen
+#define	MaxHostNameLen 64
 #endif
 
 #if	defined(IPPROTO_IP) && defined(IP_TOS)
@@ -79,7 +81,7 @@ int tos = -1;
 #endif	/* defined(IPPROTO_IP) && defined(IP_TOS) */
 
 char	*hostname;
-static char _hostname[MAXHOSTNAMELEN];
+static char _hostname[MaxHostNameLen];
 
 extern char *getenv();
 
@@ -2362,7 +2364,7 @@ int tn(int argc, char **argv)
 
 	user = getenv("USER");
 	if (user == NULL ||
-	    ((pw = getpwnam(user)) && pw->pw_uid != getuid())) {
+	    ((pw = k_getpwnam(user)) && pw->pw_uid != getuid())) {
 		if (pw = getpwuid(getuid()))
 			user = pw->pw_name;
 		else
