@@ -33,7 +33,7 @@
 
 #include <config.h>
 
-RCSID("$Id: sys_term.c,v 1.34 1996/02/26 16:58:28 d91-jda Exp $");
+RCSID("$Id: sys_term.c,v 1.39 1996/06/07 22:29:32 joda Exp $");
 
 #include "telnetd.h"
 #include "pathnames.h"
@@ -48,7 +48,7 @@ RCSID("$Id: sys_term.c,v 1.34 1996/02/26 16:58:28 d91-jda Exp $");
 
 #ifdef	NEWINIT
 #include <initreq.h>
-int	utmp_len = MAXHOSTNAMELEN;	/* sizeof(init_request.host) */
+int	utmp_len = MaxHostNameLen;	/* sizeof(init_request.host) */
 #else	/* NEWINIT*/
 # ifdef	HAVE_UTMPX_H
 # include <utmpx.h>
@@ -98,13 +98,10 @@ extern struct sysv sysv;
 #ifdef  HAVE_SYS_UIO_H
 #include <sys/uio.h>
 #endif
-#include <sys/stream.h>
-#endif
 #ifdef __hpux
 #undef SE
-#include <sys/resource.h>
-#include <sys/proc.h>
-#undef SE
+#endif
+#include <sys/stream.h>
 #endif
 #if !(defined(__sgi) || defined(__linux) || defined(_AIX)) && defined(HAVE_SYS_TTY)
 #include <sys/tty.h>
@@ -357,6 +354,9 @@ getnpty()
 static char Xline[] = "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";
 char *line = Xline;
 
+char *line_nodev;
+char *line_notty;
+
 #ifdef	CRAY
 char *myline = "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";
 #endif	/* CRAY */
@@ -372,9 +372,41 @@ static char *ptsname(int fd)
 }
 #endif
 
+#ifdef HAVE_UTMPX_H
+static char utid[32]; /* XXX larger than ut_id */
+
+void
+set_utid(void)
+{
+    int ptynum;
+    
+    line_nodev = line;
+    if(!strncmp(line, "/dev/", 5))
+	line_nodev += 5;
+
+    line_notty = line_nodev;
+    if(!strncmp(line_nodev, "tty", 3))
+	line_notty += 3;
+    else if(!strncmp(line_nodev, "pts/", 4))
+	line_notty += 4;
+    
+    /* Derive utmp ID from pty slave number */
+    if(isdigit(line_notty[0]) && sscanf(line_notty, "%d", &ptynum) == 1)
+	
+	sprintf(utid, "tn%02x", ptynum & 0xff);
+    else
+	sprintf(utid, "tn%s", line_notty);
+}
+#else
+void
+set_utid(void)
+{
+}
+#endif
+
 int getpty(int *ptynum)
 {
-#ifdef __osf__
+#ifdef __osf__ /* XXX */
         int master;
 	int slave;
 	if(openpty(&master, &slave, line, 0, 0) == 0){
@@ -1425,20 +1457,23 @@ init_env(void)
 /*
  * scrub_env()
  *
- * Remove a few things from the environment that
- * don't need to be there.
+ * Remove variables from the environment that might cause login to
+ * behave in a bad manner. To avoid this, login should be staticly
+ * linked.
  */
 
 static void scrub_env(void)
 {
+  static char *remove[] = { "LD_", "_RLD_", "LIBPATH=", "IFS=", NULL };
+
   char **cpp, **cpp2;
+  char **p;
   
   for (cpp2 = cpp = environ; *cpp; cpp++) {
-    if (strncmp(*cpp, "LD_", 3) &&
-	strncmp(*cpp, "_RLD_", 5) &&
-	strncmp(*cpp, "LIBPATH=", 8) &&
-	strncmp(*cpp, "IFS=", 4))
-      *cpp2++ = *cpp;
+    for(p = remove; *p; p++)
+      if(strncmp(*cpp, *p, strlen(*p)) == 0)
+	continue;
+    *cpp2++ = *cpp;
   }
   *cpp2 = 0;
 }
@@ -1464,6 +1499,7 @@ void start_login(char *host, int autologin, char *name)
 	register char *cp;
 	struct arg_val argv;
 	extern char *getenv(const char *);
+
 #ifdef	HAVE_UTMPX_H
 	char id_buf[3];
 	int ptynum;
@@ -1478,18 +1514,13 @@ void start_login(char *host, int autologin, char *name)
 
 	memset(&utmpx, 0, sizeof(utmpx));
 	SCPYN(utmpx.ut_user, ".telnet");
-	SCPYN(utmpx.ut_line, line + sizeof("/dev/") - 1);
+
+	SCPYN(utmpx.ut_line, line_nodev);
 	utmpx.ut_pid = pid;
-	/* Derive utmp ID from pty slave number */
-	if(sscanf(line, "%*[^0-9]%d", &ptynum) != 1 || ptynum > 255)
-	    fatal(net, "pty slave number incorrect");
-	sprintf(id_buf, "%02x", ptynum);
-	utmpx.ut_id[0] = 't';
-	utmpx.ut_id[1] = 'n';
-	utmpx.ut_id[2] = id_buf[0];
-	utmpx.ut_id[3] = id_buf[1];
+	SCPYN(utmpx.ut_id, utid);
+	
 	utmpx.ut_type = LOGIN_PROCESS;
-	(void) time(&utmpx.ut_tv.tv_sec);
+	gettimeofday(&utmpx.ut_tv, NULL);
 	if (pututxline(&utmpx) == NULL)
 		fatal(net, "pututxline failed");
 #endif
@@ -1720,106 +1751,247 @@ int addarg(struct arg_val *argv, char *val)
 
 #endif	/* NEWINIT */
 
+/*
+ * rmut()
+ *
+ * This is the function called by cleanup() to
+ * remove the utmp entry for this person.
+ */
+
+#ifdef	HAVE_UTMPX_H
+static
+void
+rmut(void)
+{
+	register f;
+	int found = 0;
+	struct utmp *u, *utmp;
+	int nutmp;
+	struct stat statbf;
+
+	struct utmpx *utxp, utmpx;
+
+	/*
+	 * This updates the utmpx and utmp entries and make a wtmp/x entry
+	 */
+
+	setutxent();
+	memset(&utmpx, 0, sizeof(utmpx));
+	strncpy(utmpx.ut_id, utid, sizeof(utmpx.ut_id));
+	utmpx.ut_type = LOGIN_PROCESS;
+	utxp = getutxid(&utmpx);
+	if (utxp) {
+	    strcpy(utxp->ut_user, "");
+	    utxp->ut_type = DEAD_PROCESS;
+	    utxp->ut_exit.e_termination = 0;
+	    utxp->ut_exit.e_exit = 0;
+	    gettimeofday(&utxp->ut_tv, NULL);
+	    pututxline(utxp);
+	    updwtmpx(WTMPX_FILE, utxp);
+	}
+	endutxent();
+}  /* end of rmut */
+#endif
+
+#if !defined(HAVE_UTMPX_H) && !(defined(CRAY) || defined(__hpux)) && BSD <= 43
+static
+void
+rmut(void)
+{
+	register f;
+	int found = 0;
+	struct utmp *u, *utmp;
+	int nutmp;
+	struct stat statbf;
+
+	f = open(utmpf, O_RDWR);
+	if (f >= 0) {
+		(void) fstat(f, &statbf);
+		utmp = (struct utmp *)malloc((unsigned)statbf.st_size);
+		if (!utmp)
+			syslog(LOG_ERR, "utmp malloc failed");
+		if (statbf.st_size && utmp) {
+			nutmp = read(f, (char *)utmp, (int)statbf.st_size);
+			nutmp /= sizeof(struct utmp);
+
+			for (u = utmp ; u < &utmp[nutmp] ; u++) {
+				if (SCMPN(u->ut_line, line+5) ||
+				    u->ut_name[0]==0)
+					continue;
+				(void) lseek(f, ((long)u)-((long)utmp), L_SET);
+				SCPYN(u->ut_name, "");
+				SCPYN(u->ut_host, "");
+				(void) time(&u->ut_time);
+				(void) write(f, (char *)u, sizeof(wtmp));
+				found++;
+			}
+		}
+		(void) close(f);
+	}
+	if (found) {
+		f = open(wtmpf, O_WRONLY|O_APPEND);
+		if (f >= 0) {
+			SCPYN(wtmp.ut_line, line+5);
+			SCPYN(wtmp.ut_name, "");
+			SCPYN(wtmp.ut_host, "");
+			(void) time(&wtmp.ut_time);
+			(void) write(f, (char *)&wtmp, sizeof(wtmp));
+			(void) close(f);
+		}
+	}
+	(void) chmod(line, 0666);
+	(void) chown(line, 0, 0);
+	line[strlen("/dev/")] = 'p';
+	(void) chmod(line, 0666);
+	(void) chown(line, 0, 0);
+}  /* end of rmut */
+#endif	/* CRAY */
+
+#ifdef __hpux
+static
+void
+rmut (char *line)
+{
+	struct utmp utmp;
+	struct utmp *utptr;
+	int fd;			/* for /etc/wtmp */
+
+	utmp.ut_type = USER_PROCESS;
+	(void) strncpy(utmp.ut_id, line+12, sizeof(utmp.ut_id));
+	(void) setutent();
+	utptr = getutid(&utmp);
+	/* write it out only if it exists */
+	if (utptr) {
+		utptr->ut_type = DEAD_PROCESS;
+		utptr->ut_time = time((long *) 0);
+		(void) pututline(utptr);
+		/* set wtmp entry if wtmp file exists */
+		if ((fd = open(wtmpf, O_WRONLY | O_APPEND)) >= 0) {
+			(void) write(fd, utptr, sizeof(utmp));
+			(void) close(fd);
+		}
+	}
+	(void) endutent();
+
+	(void) chmod(line, 0666);
+	(void) chown(line, 0, 0);
+	line[14] = line[13];
+	line[13] = line[12];
+	line[8] = 'm';
+	line[9] = '/';
+	line[10] = 'p';
+	line[11] = 't';
+	line[12] = 'y';
+	(void) chmod(line, 0666);
+	(void) chown(line, 0, 0);
+}
+#endif
+
 /*
  * cleanup()
  *
  * This is the routine to call when we are all through, to
  * clean up anything that needs to be cleaned up.
  */
-	/* ARGSUSED */
-	void
+
+#ifdef PARENT_DOES_UTMP
+
+void
 cleanup(int sig)
 {
-#ifndef	PARENT_DOES_UTMP
-# if (BSD > 43) || defined(convex)
-	char *p;
-
-	p = line + sizeof("/dev/") - 1;
-	if (logout(p))
-		logwtmp(p, "", "");
-	(void)chmod(line, 0666);
-	(void)chown(line, 0, 0);
-	*p = 'p';
-	(void)chmod(line, 0666);
-	(void)chown(line, 0, 0);
-	(void) shutdown(net, 2);
-	exit(1);
-# else
-	void rmut();
-
-	rmut();
-#ifdef HAVE_VHANGUP
-	vhangup();	/* XXX */
-#else
-#endif
-	(void) shutdown(net, 2);
-	exit(1);
-# endif
-#else	/* PARENT_DOES_UTMP */
 # ifdef	NEWINIT
-	(void) shutdown(net, 2);
-	exit(1);
+    shutdown(net, 2);
+    exit(1);
 # else	/* NEWINIT */
 #  ifdef CRAY
-	static int incleanup = 0;
-	register int t;
-	int child_status; /* status of child process as returned by waitpid */
-	int flags = WNOHANG|WUNTRACED;
-
-	/*
-	 * 1: Pick up the zombie, if we are being called
-	 *    as the signal handler.
-	 * 2: If we are a nested cleanup(), return.
-	 * 3: Try to clean up TMPDIR.
-	 * 4: Fill in utmp with shutdown of process.
-	 * 5: Close down the network and pty connections.
-	 * 6: Finish up the TMPDIR cleanup, if needed.
+    static int incleanup = 0;
+    register int t;
+    int child_status; /* status of child process as returned by waitpid */
+    int flags = WNOHANG|WUNTRACED;
+    
+    /*
+     * 1: Pick up the zombie, if we are being called
+     *    as the signal handler.
+     * 2: If we are a nested cleanup(), return.
+     * 3: Try to clean up TMPDIR.
+     * 4: Fill in utmp with shutdown of process.
+     * 5: Close down the network and pty connections.
+     * 6: Finish up the TMPDIR cleanup, if needed.
+     */
+    if (sig == SIGCHLD) {
+	while (waitpid(-1, &child_status, flags) > 0)
+	    ;	/* VOID */
+	/* Check if the child process was stopped
+	 * rather than exited.  We want cleanup only if
+	 * the child has died.
 	 */
-	if (sig == SIGCHLD) {
-		while (waitpid(-1, &child_status, flags) > 0)
-			;	/* VOID */
-		/* Check if the child process was stopped
-		 * rather than exited.  We want cleanup only if
-		 * the child has died.
-		 */
-		if (WIFSTOPPED(child_status)) {
-			return;
-		}
+	if (WIFSTOPPED(child_status)) {
+	    return;
 	}
-	t = sigblock(sigmask(SIGCHLD));
-	if (incleanup) {
+    }
+    t = sigblock(sigmask(SIGCHLD));
+    if (incleanup) {
 		sigsetmask(t);
 		return;
-	}
-	incleanup = 1;
-	sigsetmask(t);
+    }
+    incleanup = 1;
+    sigsetmask(t);
 #ifdef	UNICOS7x
-	if (secflag) {
-		/*
-		 *	We need to set ourselves back to a null
-		 *	label to clean up.
-		 */
-
-		setulvl(sysv.sy_minlvl);
-		setucmp((long)0);
-	}
+    if (secflag) {
+	/*
+	 *	We need to set ourselves back to a null
+	 *	label to clean up.
+	 */
+	
+	setulvl(sysv.sy_minlvl);
+	setucmp((long)0);
+    }
 #endif	/* UNICOS7x */
-
-	t = cleantmp(&wtmp);
-	setutent();	/* just to make sure */
+    
+    t = cleantmp(&wtmp);
+    setutent();	/* just to make sure */
 #  endif /* CRAY */
-	rmut(line);
-	close(ourpty);
-	(void) shutdown(net, 2);
+    rmut(line);
+    close(ourpty);
+    (void) shutdown(net, 2);
 #  ifdef CRAY
-	if (t == 0)
-		cleantmp(&wtmp);
+    if (t == 0)
+	cleantmp(&wtmp);
 #  endif /* CRAY */
-	exit(1);
+    exit(1);
 # endif	/* NEWINT */
-#endif	/* PARENT_DOES_UTMP */
 }
 
+#else /* PARENT_DOES_UTMP */
+
+extern void rmut(void);
+
+void
+cleanup(int sig)
+{
+#if defined(HAVE_UTMPX_H) || !defined(HAVE_LOGWTMP)
+    rmut();
+#ifdef HAVE_VHANGUP
+    vhangup(); /* XXX */
+#endif
+#else
+    char *p;
+    
+    p = line + sizeof("/dev/") - 1;
+    if (logout(p))
+	logwtmp(p, "", "");
+    chmod(line, 0666);
+    chown(line, 0, 0);
+    *p = 'p';
+    chmod(line, 0666);
+    chown(line, 0, 0);
+#endif
+    shutdown(net, 2);
+    exit(1);
+}
+
+#endif /* PARENT_DOES_UTMP */
+
 #if defined(PARENT_DOES_UTMP) && !defined(NEWINIT)
 /*
  * _utmp_sig_rcv
@@ -2062,132 +2234,3 @@ cleantmpdir(jid, tpath, user)
 }
 # endif /* CRAY */
 #endif	/* defined(PARENT_DOES_UTMP) && !defined(NEWINIT) */
-
-/*
- * rmut()
- *
- * This is the function called by cleanup() to
- * remove the utmp entry for this person.
- */
-
-#ifdef	HAVE_UTMPX_H
-	void
-rmut()
-{
-	register f;
-	int found = 0;
-	struct utmp *u, *utmp;
-	int nutmp;
-	struct stat statbf;
-
-	struct utmpx *utxp, utmpx;
-
-	/*
-	 * This updates the utmpx and utmp entries and make a wtmp/x entry
-	 */
-
-	SCPYN(utmpx.ut_line, line + sizeof("/dev/") - 1);
-	utxp = getutxline(&utmpx);
-	if (utxp) {
-		utxp->ut_type = DEAD_PROCESS;
-		utxp->ut_exit.e_termination = 0;
-		utxp->ut_exit.e_exit = 0;
-		(void) time(&utmpx.ut_tv.tv_sec);
-		utmpx.ut_tv.tv_usec = 0;
-		modutx(utxp);
-	}
-	endutxent();
-}  /* end of rmut */
-#endif
-
-#if !defined(HAVE_UTMPX_H) && !(defined(CRAY) || defined(__hpux)) && BSD <= 43
-	void
-rmut()
-{
-	register f;
-	int found = 0;
-	struct utmp *u, *utmp;
-	int nutmp;
-	struct stat statbf;
-
-	f = open(utmpf, O_RDWR);
-	if (f >= 0) {
-		(void) fstat(f, &statbf);
-		utmp = (struct utmp *)malloc((unsigned)statbf.st_size);
-		if (!utmp)
-			syslog(LOG_ERR, "utmp malloc failed");
-		if (statbf.st_size && utmp) {
-			nutmp = read(f, (char *)utmp, (int)statbf.st_size);
-			nutmp /= sizeof(struct utmp);
-
-			for (u = utmp ; u < &utmp[nutmp] ; u++) {
-				if (SCMPN(u->ut_line, line+5) ||
-				    u->ut_name[0]==0)
-					continue;
-				(void) lseek(f, ((long)u)-((long)utmp), L_SET);
-				SCPYN(u->ut_name, "");
-				SCPYN(u->ut_host, "");
-				(void) time(&u->ut_time);
-				(void) write(f, (char *)u, sizeof(wtmp));
-				found++;
-			}
-		}
-		(void) close(f);
-	}
-	if (found) {
-		f = open(wtmpf, O_WRONLY|O_APPEND);
-		if (f >= 0) {
-			SCPYN(wtmp.ut_line, line+5);
-			SCPYN(wtmp.ut_name, "");
-			SCPYN(wtmp.ut_host, "");
-			(void) time(&wtmp.ut_time);
-			(void) write(f, (char *)&wtmp, sizeof(wtmp));
-			(void) close(f);
-		}
-	}
-	(void) chmod(line, 0666);
-	(void) chown(line, 0, 0);
-	line[strlen("/dev/")] = 'p';
-	(void) chmod(line, 0666);
-	(void) chown(line, 0, 0);
-}  /* end of rmut */
-#endif	/* CRAY */
-
-#ifdef __hpux
-rmut (line)
-char *line;
-{
-	struct utmp utmp;
-	struct utmp *utptr;
-	int fd;			/* for /etc/wtmp */
-
-	utmp.ut_type = USER_PROCESS;
-	(void) strncpy(utmp.ut_id, line+12, sizeof(utmp.ut_id));
-	(void) setutent();
-	utptr = getutid(&utmp);
-	/* write it out only if it exists */
-	if (utptr) {
-		utptr->ut_type = DEAD_PROCESS;
-		utptr->ut_time = time((long *) 0);
-		(void) pututline(utptr);
-		/* set wtmp entry if wtmp file exists */
-		if ((fd = open(wtmpf, O_WRONLY | O_APPEND)) >= 0) {
-			(void) write(fd, utptr, sizeof(utmp));
-			(void) close(fd);
-		}
-	}
-	(void) endutent();
-
-	(void) chmod(line, 0666);
-	(void) chown(line, 0, 0);
-	line[14] = line[13];
-	line[13] = line[12];
-	line[8] = 'm';
-	line[9] = '/';
-	line[10] = 'p';
-	line[11] = 't';
-	line[12] = 'y';
-	(void) chmod(line, 0666);
-	(void) chown(line, 0, 0);
-}
-#endif
