@@ -35,7 +35,7 @@
 #include <config.h>
 #endif
 
-RCSID("$Id: telnetd.c,v 1.17 1996/05/05 04:39:52 assar Exp $");
+RCSID("$Id: telnetd.c,v 1.19 1996/06/04 01:01:27 joda Exp $");
 
 #include "telnetd.h"
 #include "pathnames.h"
@@ -789,13 +789,10 @@ terminaltypeok(s)
     return(1);
 }
 
-#ifndef	MAXHOSTNAMELEN
-#define	MAXHOSTNAMELEN 64
-#endif	/* MAXHOSTNAMELEN */
 
 char *hostname;
-char host_name[MAXHOSTNAMELEN];
-char remote_host_name[MAXHOSTNAMELEN];
+char host_name[MaxHostNameLen];
+char remote_host_name[MaxHostNameLen];
 
 #ifndef	convex
 extern void telnet P((int, int));
@@ -822,6 +819,7 @@ void doit(struct sockaddr_in *who)
 	ourpty = getpty(&ptynum);
 	if (ourpty < 0)
 		fatal(net, "All network ports in use");
+	set_utid();
 #else
 	for (;;) {
 		char *lp;
