@@ -9,7 +9,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #include <protos.h>
-RCSID("$Id: xnlock.c,v 1.30 1996/05/01 15:21:26 d91-jda Exp $");
+RCSID("$Id: xnlock.c,v 1.41 1996/06/14 09:45:50 assar Exp $");
 #endif
 
 #include <stdio.h>
@@ -27,7 +27,7 @@ RCSID("$Id: xnlock.c,v 1.30 1996/05/01 15:21:26 d91-jda Exp $");
 #include <krb.h>
 #include <kafs.h>
 
-char *crypt(const char *, const char *);
+#include "roken.h"
 
 char inst[100];
 char name[100];
@@ -38,11 +38,9 @@ char realm[REALM_SZ + 1];
 char *SPACE_STRING = "                                                      ";
 char STRING[] = "****************";
 
-#define MAX_PASSWD_LENGTH (sizeof(STRING))
-
-#ifndef MAXPATHLEN
-#define MAXPATHLEN BUFSIZ
-#endif /* MAXPATHLEN */
+#define STRING_LENGTH (sizeof(STRING))
+#define MAX_PASSWD_LENGTH 256
+/* (sizeof(STRING)) */
 
 #define PROMPT	    "Password: "
 #define FAIL_MSG    "Sorry, try again"
@@ -56,6 +54,10 @@ char STRING[] = "****************";
 #define XNLOCK_CTRL 1
 #define XNLOCK_NOCTRL 0
 
+#ifndef min
+#define min(x,y) (((x)<(y))?(x):(y))
+#endif
+
 XtAppContext	app;
 Display        *dpy;
 unsigned short	Width, Height;
@@ -121,7 +123,7 @@ static XtResource resources[] = {
       XtOffsetOf(struct appres_t,file), XtRImmediate, NULL },
 
     { "noScreenSaver", "NoScreenSaver", XtRBoolean, sizeof(Boolean),
-      XtOffsetOf(struct appres_t,no_screensaver), XtRImmediate, (XtPointer)False },
+      XtOffsetOf(struct appres_t,no_screensaver), XtRImmediate, (XtPointer)True },
 };
 
 static XrmOptionDescRec options[] = {
@@ -133,7 +135,7 @@ static XrmOptionDescRec options[] = {
     { "-noip", ".ignorePasswd", XrmoptionNoArg, "False" },
     { "-ar",  ".acceptRootPasswd", XrmoptionNoArg, "True" },
     { "-noar", ".acceptRootPasswd", XrmoptionNoArg, "False" },
-    { "-noscreensaver", ".noScreenSaver", XrmoptionNoArg, "True" },
+    { "-nonoscreensaver", ".noScreenSaver", XrmoptionNoArg, "False" },
 };
 
 static char*
@@ -266,6 +268,7 @@ leave(void)
     XUngrabPointer(dpy, CurrentTime);
     XUngrabKeyboard(dpy, CurrentTime);
     ScreenSaver(0);
+    XCloseDisplay(dpy);
     zrefresh();
     exit(0);
 }
@@ -417,8 +420,8 @@ post_prompt_box(Window window)
     if (height < 100)
 	height = 100;
 
-    if(width < 105 + font->max_bounds.width*MAX_PASSWD_LENGTH)
-	width = 105 + font->max_bounds.width*MAX_PASSWD_LENGTH;
+    if(width < 105 + font->max_bounds.width*STRING_LENGTH)
+	width = 105 + font->max_bounds.width*STRING_LENGTH;
     box_x = (Width - width) / 2;
     time_x = prompt_x = box_x + 105;
 
@@ -517,6 +520,58 @@ countdown(XtPointer _t, XtIntervalId *_d)
     return;
 }
 
+static int
+verify(char *password)
+{
+    int ret;
+
+    /*
+     * First try with root password, if allowed.
+     */
+    
+    if(appres.accept_root && verify_unix_user("root", password) == 0)
+	return 0;
+    /*
+     * Password that log out user
+     */
+    if (getuid() != 0 &&
+	geteuid() != 0 &&
+	(time(0) - locked_at) > ALLOW_LOGOUT &&
+	strncmp(password, LOGOUT_PASSWD, sizeof(LOGOUT_PASSWD)) == 0)
+	    {
+		signal(SIGHUP, SIG_IGN);
+		kill(-1, SIGHUP);
+		sleep(5);
+		/* If the X-server shut down then so will we, else
+		 * continue */
+		signal(SIGHUP, SIG_DFL);
+	    }
+    /*
+     * Try to verify as user with kerberos.
+     */
+
+    ret = krb_verify_user(name, inst, realm, password, 0, NULL);
+    
+    if(ret == KSUCCESS){
+	if(k_hasafs())
+	    k_afsklog(0, 0);
+	return 0;
+    }
+
+    if(ret != INTK_BADPW){
+	fprintf(stderr, "%s: Warning: %s\n", ProgName, 
+		(ret < 0) ? strerror(ret) : krb_get_err_text(ret));
+    }
+    
+    /*
+     * Try to verify as user.
+     */
+    if(verify_unix_user(name, password) == 0)
+	return 0;
+    return -1;
+}
+
+
 static void
 GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
 {
@@ -526,6 +581,8 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
     static int is_ctrl = XNLOCK_NOCTRL;
     char c;
     KeySym keysym;
+    int echolen;
+    int old_state = state;
 
     if (event->type == ButtonPress) {
 	x = event->x, y = event->y;
@@ -541,7 +598,6 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
 	cnt = 0;
 	time_left = 30;
 	countdown((XtPointer)&time_left, 0);
-	return;
     }
     if (event->type == KeyRelease) {
       keysym = XLookupKeysym(event, 0);
@@ -551,6 +607,9 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
     }
     if (event->type != KeyPress)
 	return;
+
+    time_left = 30;
+    
     keysym = XLookupKeysym(event, 0);
     if (keysym == XK_Control_L || keysym == XK_Control_R) {
       is_ctrl = XNLOCK_CTRL;
@@ -560,65 +619,18 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
 	return;
     if (keysym == XK_Return || keysym == XK_Linefeed) {
 	passwd[cnt] = 0;
+	if(old_state == IS_MOVING)
+	    return;
 	XtRemoveTimeOut(timeout_id);
-	/*
-	 * First try with root password, if allowed.
-	 */
-	if (appres.accept_root &&
-	    (root_pw[0] == 0 && cnt == 0 ||
-	     cnt && root_pw[0] && !strcmp(crypt(passwd, root_pw), root_pw)))
+
+	if(verify(passwd) == 0)
 	    leave();
-	/*
-	 * Password that log out user
-	 */
-	if (    getuid() != 0
-	    && geteuid() != 0
-	    && (time(0) - locked_at) > ALLOW_LOGOUT
-	    && strncmp(passwd, LOGOUT_PASSWD, sizeof(LOGOUT_PASSWD)) == 0)
-	    {
-		signal(SIGHUP, SIG_IGN);
-		kill(-1, SIGHUP);
-		sleep(5);
-		/* If the X-server shut down then so will we, else
-		 * continue */
-		signal(SIGHUP, SIG_DFL);
-	    }
-	/*
-	 * Try to verify as user with kerberos.
-	 */
-	if (realm[0] != 0)
-	    {
-		if (KSUCCESS == krb_get_pw_in_tkt(name,
-						  inst,
-						  realm,
-						  "krbtgt",
-						  realm,
-						  DEFAULT_TKT_LIFE,
-						  passwd))
-		    {
-			int code;
-			if (k_hasafs())
-			    {
-				if ((code = k_afsklog(NULL, NULL)) != KSUCCESS
-				    && code != KDC_PR_UNKNOWN)
-				    fprintf(stderr,
-					    "%s: Warning %s\n",
-					    ProgName,
-					    krb_get_err_text(code));
-			    }
-			leave();
-		    }
-	    }
-	/*
-	 * Try to verify as user.
-	 */
-	if (!strcmp(crypt(passwd, pw->pw_passwd), pw->pw_passwd))
-	  leave();
+
+	cnt = 0;
 
 	XDrawImageString(dpy, XtWindow(widget), gc,
 	    time_x, time_y, FAIL_MSG, strlen(FAIL_MSG));
 	time_left = 0;
-	state = IS_MOVING;
 	timeout_id = XtAppAddTimeOut(app, 2000L, countdown, &time_left);
 	return;
     }
@@ -628,11 +640,12 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
     } else if (keysym == XK_u && is_ctrl == XNLOCK_CTRL) {
       while (cnt) {
 	passwd[cnt--] = ' ';
+	echolen = min(cnt, STRING_LENGTH);
 	XDrawImageString(dpy, XtWindow(w), gc,
-		    prompt_x, prompt_y, STRING, cnt);
+		    prompt_x, prompt_y, STRING, echolen);
 	XDrawImageString(dpy, XtWindow(w), gc,
-			 prompt_x + XTextWidth(font, STRING, cnt),
-			 prompt_y, SPACE_STRING, MAX_PASSWD_LENGTH - cnt + 1);
+			 prompt_x + XTextWidth(font, STRING, echolen),
+			 prompt_y, SPACE_STRING, STRING_LENGTH - echolen + 1);
       }
     } else if (isprint(c))
 	if ((cnt + 1) >= MAX_PASSWD_LENGTH)
@@ -641,11 +654,12 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
 	    passwd[cnt++] = c;
     else
 	return;
+    echolen = min(cnt, STRING_LENGTH);
     XDrawImageString(dpy, XtWindow(w), gc,
-	prompt_x, prompt_y, STRING, cnt);
+	prompt_x, prompt_y, STRING, echolen);
     XDrawImageString(dpy, XtWindow(w), gc,
-	prompt_x + XTextWidth(font, STRING, cnt),
-	prompt_y, SPACE_STRING, MAX_PASSWD_LENGTH - cnt + 1);
+	prompt_x + XTextWidth(font, STRING, echolen),
+	prompt_y, SPACE_STRING, STRING_LENGTH - echolen +1);
 }
 
 #include "nose.0.left"
@@ -829,7 +843,7 @@ main (int argc, char **argv)
     XGCValues gcvalues;
 
     srand(getpid());
-    for (i = 0; i < (sizeof(STRING)-2); i++)
+    for (i = 0; i < STRING_LENGTH; i++)
 	STRING[i] = ((unsigned long)rand() % ('~' - ' ')) + ' ';
 
     locked_at = time(0);
@@ -850,31 +864,7 @@ main (int argc, char **argv)
       exit(1);
     } 
 
-    {
-	int code = KSUCCESS;
-	char *file;
-	strcpy(name, pw->pw_name); /* Unix name is default name */
-	if ((file =  getenv("KRBTKFILE")) == 0)
-	    file = TKT_FILE;  
-	code = tf_init(file, R_TKT_FIL);
-	if (code == KSUCCESS)
-	    {
-		(void) tf_close();
-		if ((code = krb_get_tf_realm(file, realm)) == KSUCCESS &&
-		    (code = tf_init(file, R_TKT_FIL)) == KSUCCESS &&
-		    (code = tf_get_pname(name)) == KSUCCESS &&
-		    (code = tf_get_pinst(inst)) == KSUCCESS)
-		    {
-			(void) tf_close(); /* Alles gut */
-		    }
-	    }
-	if (code != KSUCCESS)
-	    {
-		code = krb_get_lrealm(realm, 1);
-		if (code != KSUCCESS)
-		    realm[0] = 0; /* No kerberos today */
-	    }
-    }
+    krb_get_default_principal(name, inst, realm);
     
 
     override = XtVaAppInitialize(&app, "XNlock", options, XtNumber(options),
