@@ -1,19 +1,11 @@
 /*
  * Add here functions that don't have a prototype on your system.
  *
- * $Locker:  $
- *
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/include/protos.h,v 1.18 1996/04/28 17:45:16 d91-jda Exp $
+ * $Id: protos.h,v 1.20 1996/06/12 21:28:37 bg Exp $
  *
  */
 
 
-/* bcopy and friendes does not really exist but are used anyway! */
-#include <memory.h>
-#define bcopy(f,t,n)    memcpy((t), (f), (n))
-#define bzero(s,n)      memset((s), 0, (n))
-#define bcmp(a,b,n)     memcmp((a), (b), (n))
-
 #if defined(__GNUC__) && SunOS == 4
 
 /* To get type fd_set */
