@@ -35,7 +35,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: admin_server.c,v 1.25 1996/04/23 07:11:22 d91-jda Exp $");
+RCSID("$Id: admin_server.c,v 1.28 1996/06/15 11:37:23 assar Exp $");
 
 /* Almost all procs and such need this, so it is global */
 admin_params prm;		/* The command line parameters struct */
@@ -121,8 +121,8 @@ byebye(void)			/* say goodnight gracie */
 static void
 clear_secrets(void)
 {
-    bzero((char *)server_parm.master_key, sizeof(server_parm.master_key));
-    bzero((char *)server_parm.master_key_schedule,
+    memset(server_parm.master_key, 0, sizeof(server_parm.master_key));
+    memset(server_parm.master_key_schedule, 0,
 	  sizeof(server_parm.master_key_schedule));
     server_parm.master_key_version = 0L;
     return;
@@ -178,7 +178,7 @@ process_client(int fd, struct sockaddr_in *who)
       pdat = (char *) dat;
       retcode = htonl((u_int32_t) KADM_DB_INUSE);
       (void) strncpy(pdat, KADM_ULOSE, KADM_VERSIZE);
-      bcopy((char *)&retcode, &pdat[KADM_VERSIZE], sizeof(retcode));
+      memcpy(pdat+KADM_VERSIZE, &retcode, sizeof(retcode));
       goto out;
     } else if (!status) {
       k_log("no service %s.%s",server_parm.sname, server_parm.sinst);
@@ -186,12 +186,12 @@ process_client(int fd, struct sockaddr_in *who)
     }
 
     copy_to_key(&service.key_low, &service.key_high, skey);
-    bzero((char *)&service, sizeof(service));
+    memset(&service, 0, sizeof(service));
     kdb_encrypt_key (&skey, &skey, &server_parm.master_key,
 		     server_parm.master_key_schedule, DES_DECRYPT);
     (void) krb_set_key((char *)skey, 0); /* if error, will show up when
 					    rd_req fails */
-    bzero((char *)skey, sizeof(skey));
+    memset(skey, 0, sizeof(skey));
 
     while (1) {
 	if ((retval = krb_net_read(fd, (char *)&dlen, sizeof(u_short))) !=
@@ -337,7 +337,6 @@ kadm_listen(void)
 		/* child */
 		(void) close(admin_fd);
 #endif /* DEBUG */
-#ifdef MULTIHOMED_KADMIN
 		/*
 		 * If we are multihomed we need to figure out which
 		 * local address that is used this time since it is
@@ -347,7 +346,6 @@ kadm_listen(void)
 		getsockname(peer_fd,
 			    (struct sockaddr *)&server_parm.admin_addr,
 			    &pid);
-#endif
 		/* do stuff */
 		process_client (peer_fd, &peer);
 #ifndef DEBUG
@@ -380,11 +378,11 @@ main(int argc, char **argv)		/* admin_server main routine */
 
     /* initialize the admin_params structure */
     prm.sysfile = KADM_SYSLOG;		/* default file name */
-    prm.inter = 1;
+    prm.inter = 0;
 
-    bzero(krbrlm, sizeof(krbrlm));
+    memset(krbrlm, 0, sizeof(krbrlm));
 
-    while ((c = getopt(argc, argv, "f:hnd:a:r:")) != EOF)
+    while ((c = getopt(argc, argv, "f:hmnd:a:r:")) != EOF)
 	switch(c) {
 	case 'f':			/* Syslog file name change */
 	    prm.sysfile = optarg;
@@ -392,6 +390,9 @@ main(int argc, char **argv)		/* admin_server main routine */
 	case 'n':
 	    prm.inter = 0;
 	    break;
+	case 'm':
+	    prm.inter = 1;
+	    break;
 	case 'a':			/* new acl directory */
 	    acldir = optarg;
 	    break;
