@@ -6,7 +6,9 @@
 #include <ctype.h>
 #include <string.h>
 
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
 
 #if TIME_WITH_SYS_TIME
 #include <sys/time.h>
@@ -19,15 +21,21 @@
 #endif /* !HAVE_SYS_TIME_H */
 #endif /* !TIME_WITH_SYS_TIME */
 
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
+#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
+#endif
 
 #include <errno.h>
 #include <signal.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 extern char *optarg;
 extern int optind; /*, opterr; */
@@ -35,16 +43,27 @@ extern int optind; /*, opterr; */
 #ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
 #endif /* HAVE_SYS_RESOURCE_H */
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
+#endif
+#ifdef HAVE_PWD_H
 #include <pwd.h>
+#endif
 
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
+#endif
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
+#endif
 
+#ifdef HAVE_SYSLOG_H
 #include <syslog.h>
+#endif
 
-/* #include <time.h> */
 #include <com_err.h>
 #include <ss/ss.h>
 
