@@ -35,7 +35,7 @@ unwraps wrapped packets and calls the appropriate server subroutine
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadm_ser_wrap.c,v 1.13 1996/03/25 13:11:23 bg Exp $");
+RCSID("$Id: kadm_ser_wrap.c,v 1.17 1996/06/11 12:06:50 bg Exp $");
 
 /* GLOBAL */
 Kadm_Server server_parm;
@@ -49,7 +49,6 @@ kadm_ser_init(int inter, char *realm)
           			/* interactive or from file */
              
 {
-  struct servent *sep;
   struct hostent *hp;
   char hostname[MaxHostNameLen];
 
@@ -64,22 +63,15 @@ kadm_ser_init(int inter, char *realm)
 
   server_parm.admin_fd = -1;
   /* setting up the addrs */
-  bzero((char *)&server_parm.admin_addr,sizeof(server_parm.admin_addr));
+  memset(&server_parm.admin_addr,0, sizeof(server_parm.admin_addr));
 
-  if ((sep = getservbyname(KADM_SNAME, "tcp")) == NULL){
-    fprintf(stderr, "Warning: %s/tcp service not found.\n", KADM_SNAME);
-    server_parm.admin_addr.sin_port = htons(751);
-  }else
-    server_parm.admin_addr.sin_port = sep->s_port;
+  server_parm.admin_addr.sin_port = k_getportbyname (KADM_SNAME,
+						     "tcp",
+						     htons(751));
   server_parm.admin_addr.sin_family = AF_INET;
   if ((hp = gethostbyname(hostname)) == NULL)
       return KADM_NO_HOSTNAME;
-#ifdef MULTIHOMED_KADMIN
   server_parm.admin_addr.sin_addr.s_addr = INADDR_ANY;
-#else
-  bcopy(hp->h_addr, (char *) &server_parm.admin_addr.sin_addr.s_addr,
-	hp->h_length);
-#endif
 				/* setting up the database */
   if (kdb_get_master_key((inter==1), &server_parm.master_key,
 			 server_parm.master_key_schedule) != 0)
@@ -102,7 +94,7 @@ static void errpkt(u_char **dat, int *dat_len, int code)
     pdat = (char *) *dat;
     retcode = htonl((u_int32_t) code);
     (void) strncpy(pdat, KADM_ULOSE, KADM_VERSIZE);
-    bcopy((char *)&retcode, &pdat[KADM_VERSIZE], sizeof(u_int32_t));
+    memcpy(&pdat[KADM_VERSIZE], (char *)&retcode, sizeof(u_int32_t));
     return;
 }
 
@@ -135,7 +127,7 @@ kadm_ser_in(u_char **dat, int *dat_len)
 	return KADM_LENGTH_ERROR;
     in_len += retc;
     authent.length = *dat_len - r_len - KADM_VERSIZE - sizeof(u_int32_t);
-    bcopy((char *)(*dat) + in_len, (char *)authent.dat, authent.length);
+    memcpy((char *)authent.dat, (char *)(*dat) + in_len, authent.length);
     authent.mbz = 0;
     /* service key should be set before here */
     if ((retc = krb_rd_req(&authent, server_parm.sname, server_parm.sinst,
@@ -145,7 +137,7 @@ kadm_ser_in(u_char **dat, int *dat_len)
 	return retc + krb_err_base;
     }
 
-#define clr_cli_secrets() {bzero((char *)sess_sched, sizeof(sess_sched)); bzero((char *)ad.session, sizeof(ad.session));}
+#define clr_cli_secrets() {memset(sess_sched, 0, sizeof(sess_sched)); memset(ad.session, 0,sizeof(ad.session));}
 
     in_st = *dat + *dat_len - r_len;
 #ifdef NOENCRYPTION
@@ -159,7 +151,7 @@ kadm_ser_in(u_char **dat, int *dat_len)
 	return KADM_BAD_CHK;
     }
 #ifdef NOENCRYPTION
-    bzero(sess_sched, sizeof(sess_sched));
+    memset(sess_sched, 0, sizeof(sess_sched));
 #else
     des_key_sched(&ad.session, sess_sched);
 #endif
@@ -172,20 +164,24 @@ kadm_ser_in(u_char **dat, int *dat_len)
     }
     switch (msg_st.app_data[0]) {
     case CHANGE_PW:
-	retval = kadm_ser_cpw(msg_st.app_data+1,(int) msg_st.app_length,&ad,
-			      &retdat, &retlen);
+	retval = kadm_ser_cpw(msg_st.app_data+1,(int) msg_st.app_length - 1,
+			      &ad, &retdat, &retlen);
 	break;
     case ADD_ENT:
-	retval = kadm_ser_add(msg_st.app_data+1,(int) msg_st.app_length,&ad,
-			      &retdat, &retlen);
+	retval = kadm_ser_add(msg_st.app_data+1,(int) msg_st.app_length - 1,
+			      &ad, &retdat, &retlen);
 	break;
     case GET_ENT:
-	retval = kadm_ser_get(msg_st.app_data+1,(int) msg_st.app_length,&ad,
-			      &retdat, &retlen);
+	retval = kadm_ser_get(msg_st.app_data+1,(int) msg_st.app_length - 1,
+			      &ad, &retdat, &retlen);
 	break;
     case MOD_ENT:
-	retval = kadm_ser_mod(msg_st.app_data+1,(int) msg_st.app_length,&ad,
-			      &retdat, &retlen);
+	retval = kadm_ser_mod(msg_st.app_data+1,(int) msg_st.app_length - 1,
+			      &ad, &retdat, &retlen);
+	break;
+    case DEL_ENT:
+	retval = kadm_ser_delete(msg_st.app_data + 1, msg_st.app_length - 1, 
+				 &ad, &retdat, &retlen);
 	break;
     default:
 	clr_cli_secrets();
@@ -198,11 +194,11 @@ kadm_ser_in(u_char **dat, int *dat_len)
 					  sizeof(u_int32_t)));
     (void) strncpy((char *)tmpdat, KADM_VERSTR, KADM_VERSIZE);
     retval = htonl((u_int32_t)retval);
-    bcopy((char *)&retval, (char *)tmpdat + KADM_VERSIZE, sizeof(u_int32_t));
+    memcpy((char *)tmpdat + KADM_VERSIZE, (char *)&retval, sizeof(u_int32_t));
     if (retlen) {
-	bcopy((char *)retdat, (char *)tmpdat + KADM_VERSIZE + sizeof(u_int32_t),
-	      retlen);
-	free((char *)retdat);
+        memcpy((char *)tmpdat + KADM_VERSIZE + sizeof(u_int32_t), retdat,
+	       retlen);
+	free(retdat);
     }
     /* slop for mk_priv stuff */
     *dat = (u_char *) malloc((unsigned) (retlen + KADM_VERSIZE +
