@@ -36,7 +36,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadmin.c,v 1.18 1996/03/25 13:11:25 bg Exp $");
+RCSID("$Id: kadmin.c,v 1.26 1996/06/14 09:44:41 assar Exp $");
 
 #define BAD_PW 1
 #define GOOD_PW 0
@@ -53,6 +53,8 @@ RCSID("$Id: kadmin.c,v 1.18 1996/03/25 13:11:25 bg Exp $");
 extern ss_request_table admin_cmds;
 
 static char myname[ANAME_SZ];
+static char myinst[INST_SZ];
+static char myrealm[REALM_SZ];
 static char default_realm[REALM_SZ]; /* default kerberos realm */
 static char krbrlm[REALM_SZ];	/* current realm being administered */
 static int multiple = 0;	/* Allow multiple requests per ticket */
@@ -120,7 +122,7 @@ get_expdate(Kadm_vals *vals)
     time_t when=0;
     struct tm edate;
 
-    bzero(&edate, sizeof(edate));
+    memset(&edate, 0, sizeof(edate));
     do {
         printf("Expiration date (enter yyyy-mm-dd) ?  [%.24s]  ",
              asctime(k_localtime(&vals->exp_date)));
@@ -168,23 +170,23 @@ get_password(u_int32_t *low, u_int32_t *high, char *prompt, int byteswap)
     if (strlen(new_passwd) == 0) {
     	printf("Using random password.\n");
 #ifdef NOENCRYPTION
-	bzero((char *) newkey, sizeof(newkey));
+	memset(newkey, 0, sizeof(newkey));
 #else
 	des_new_random_key(&newkey);
 #endif
     } else {
 #ifdef NOENCRYPTION
-      bzero((char *) newkey, sizeof(newkey));
+      memset(newkey, 0, sizeof(newkey));
 #else
       des_string_to_key(new_passwd, &newkey);
 #endif
-      bzero(new_passwd, sizeof(new_passwd));
+      memset(new_passwd, 0, sizeof(new_passwd));
     }
 
-    bcopy((char *) newkey,(char *)low,4);
-    bcopy((char *)(((int32_t *) newkey) + 1), (char *)high,4);
+    memcpy(low, newkey, 4);
+    memcpy(high, ((char *)newkey) + 4, 4);
 
-    bzero((char *) newkey, sizeof(newkey));
+    memset(newkey, 0, sizeof(newkey));
 
 #ifdef NOENCRYPTION
     *low = 1;
@@ -207,7 +209,7 @@ get_admin_password(void)
 
     if (multiple) {
 	/* If admin tickets exist and are valid, just exit. */
-	bzero(&c, sizeof(c));
+	memset(&c, 0, sizeof(c));
 	if (krb_get_cred(PWSERV_NAME, KADM_SINST, krbrlm, &c) == KSUCCESS)
 	    /* 
 	     * If time is less than lifetime - FUDGE_VALUE after issue date,
@@ -219,18 +221,18 @@ get_admin_password(void)
 	ticket_life = DEFAULT_TKT_LIFE;
     }
     
-    if (princ_exists(myname, "admin", krbrlm) != PE_NO) {
+    if (princ_exists(myname, myinst, myrealm) != PE_NO) {
 	if (read_long_pw_string(admin_passwd, sizeof(admin_passwd)-1,
 				"Admin password:", 0)) {
 	    fprintf(stderr, "Error reading admin password.\n");
 	    goto bad;
 	}
-	status = krb_get_pw_in_tkt(myname, "admin", krbrlm, PWSERV_NAME, 
+	status = krb_get_pw_in_tkt(myname, myinst, myrealm, PWSERV_NAME, 
 				   KADM_SINST, ticket_life, admin_passwd);
-	bzero(admin_passwd, sizeof(admin_passwd));
+	memset(admin_passwd, 0, sizeof(admin_passwd));
 
 	/* Initialize non shared random sequence from session key. */
-	bzero(&c, sizeof(c));
+	memset(&c, 0, sizeof(c));
 	krb_get_cred(PWSERV_NAME, KADM_SINST, krbrlm, &c);
 	des_init_random_number_generator(&c.session);
     }
@@ -241,7 +243,8 @@ get_admin_password(void)
     case GT_PW_OK:
 	return(GOOD_PW);
     case KDC_PR_UNKNOWN:
-	printf("Principal %s.admin@%s does not exist.\n", myname, krbrlm);
+	printf("Principal %s%s%s@%s does not exist.\n", myname, 
+	       *myinst ? "." : "", myinst, myrealm);
 	goto bad;
     case GT_PW_BADPW:
 	printf("Incorrect admin password.\n");
@@ -253,7 +256,7 @@ get_admin_password(void)
     }
     
  bad:
-    bzero(admin_passwd, sizeof(admin_passwd));
+    memset(admin_passwd, 0, sizeof(admin_passwd));
     (void) dest_tkt();
     return(BAD_PW);
 }
@@ -294,8 +297,10 @@ do_init(int argc, char **argv)
     int c;
     int tflag;
     char tktstring[MaxPathLen];
+    int k_errno;
     
-    bzero(myname, sizeof(myname));
+    *myname = '\0';
+    strcpy (myinst, "admin");
 
     /* 
      * This is only as a default/initial realm; we don't care 
@@ -311,19 +316,24 @@ do_init(int argc, char **argv)
      * don't initialize.
      */
     if (kadm_init_link(PWSERV_NAME, KRB_MASTER, krbrlm) != KADM_SUCCESS)
-      bzero(krbrlm, sizeof(krbrlm));
+      *krbrlm = '\0';
     else
       strcpy(krbrlm, default_realm);
+    strcpy (myrealm, krbrlm);
 
     tflag = 0;
 
     while ((c = getopt(argc, argv, "u:r:mt")) != EOF) 
       switch (c) {
       case 'u':
-	strncpy(myname, optarg, sizeof(myname) - 1);
+	if((k_errno = kname_parse(myname, myinst, myrealm, optarg))
+	   != KSUCCESS) {
+	     fprintf (stderr, "%s: %s\n", argv[0], krb_get_err_text(k_errno));
+	     exit (1);
+	}
 	break;
       case 'r':
-	bzero(default_realm, sizeof(default_realm));
+	memset(default_realm, 0, sizeof(default_realm));
 	strncpy(default_realm, optarg, sizeof(default_realm) - 1);
 	break;
       case 'm':
@@ -339,16 +349,25 @@ do_init(int argc, char **argv)
     if (optind < argc)
       usage();
     if (!myname[0]) {
-      pw = getpwuid((int) getuid());
-      if (!pw) {
-	fprintf(stderr,
-		"You aren't in the password file.  Who are you?\n");
-	exit(1);
-      }
-      (void) strcpy(myname, pw->pw_name);
+	char n[ANAME_SZ], i[INST_SZ], r[REALM_SZ];
+	if(krb_get_default_principal(n, i, r) >= 0){
+	    strcpy(myname, n);
+	    if(*i)
+		strcpy(myinst, i);
+	    if(*r)
+		strcpy(myrealm, r);
+	}else{
+	    pw = getpwuid((int) getuid());
+	    if (!pw) {
+		fprintf(stderr,
+			"You aren't in the password file.  Who are you?\n");
+		exit(1);
+	    }
+	    (void) strcpy(myname, pw->pw_name);
+	}	
     }
     if (!tflag) {
-      (void) sprintf(tktstring, "/tmp/tkt_adm_%d",(int)getpid());
+      (void) sprintf(tktstring, TKT_ROOT "_adm_%d",(int)getpid());
       krb_set_tkt_string(tktstring);
     }
 }
@@ -381,8 +400,8 @@ setvals(Kadm_vals *vals, char *string)
     char realm[REALM_SZ];
     int status = KADM_SUCCESS;
 
-    bzero(vals, sizeof(*vals));
-    bzero(realm, sizeof(realm));
+    memset(vals, 0, sizeof(*vals));
+    memset(realm, 0, sizeof(realm));
 
     SET_FIELD(KADM_NAME,vals->fields);
     SET_FIELD(KADM_INST,vals->fields);
@@ -443,7 +462,7 @@ change_password(int argc, char **argv)
 	    }
 	} else
 	    printf("Error reading password; password unchanged\n");
-	bzero((char *)&new, sizeof(new));
+	memset(&new, 0, sizeof(new));
 	if (!multiple)
 	    clean_up();
     }
@@ -522,11 +541,11 @@ change_key(int argc, char **argv)
 	(void) printf("New DES key for %s: ", argv[1]);
 	
 	if (getkey(newkey)) {
-	    bcopy((char *) newkey,(char *)&new.key_low,4);
-	    bcopy((char *)(((int32_t *) newkey) + 1), (char *)&new.key_high,4);
+	    memcpy(&new.key_low, newkey, 4);
+	    memcpy(&new.key_high, ((char *)newkey) + 4, 4);
 	    printf("Entered key for %s: ", argv[1]);
 	    printkey(newkey);
-	    bzero(newkey, sizeof(newkey));
+	    memset(newkey, 0, sizeof(newkey));
 
 	    status = kadm_mod(&old, &new);
 	    if (status == KADM_SUCCESS) {
@@ -537,7 +556,7 @@ change_key(int argc, char **argv)
 	    }
 	} else
 	    printf("Error reading key; key unchanged\n");
-	bzero((char *)&new, sizeof(new));
+	memset(&new, 0, sizeof(new));
 	if (!multiple)
 	    clean_up();
     }
@@ -559,8 +578,8 @@ change_admin_password(int argc, char **argv)
 	printf("Usage: change_admin_password\n");
 	return;
     }
-    if (get_pw_new_pwd(pword, sizeof(pword), myname, "admin",
-		       default_realm, 1) == 0) {
+    if (get_pw_new_pwd(pword, sizeof(pword), myname, myinst,
+		       myrealm, 1) == 0) {
 	 des_string_to_key(pword, &newkey);
 	 status = kadm_change_pw_plain(newkey, pword, &pw_msg);
 	 if(status == KADM_INSECURE_PW)
@@ -569,8 +588,8 @@ change_admin_password(int argc, char **argv)
 	      printf("Admin password changed\n");
 	 else
 	      printf("kadm error: %s\n",error_message(status));
-	 bzero((char *)newkey, sizeof(newkey));
-	 bzero(pword, sizeof(pword));
+	 memset(newkey, 0, sizeof(newkey));
+	 memset(pword, 0, sizeof(pword));
     }
     if (!multiple)
 	clean_up();
@@ -602,10 +621,15 @@ add_new_key(int argc, char **argv)
 	    return;
 	
 	/* This is the default maximum lifetime for new principals. */
-	if (krb_life_to_time(0, 162) >= 24*60*60)
+	if (strcmp(new.instance, "admin") == 0)
+	  new.max_life = 1 + (CLOCK_SKEW/(5*60)); /* 5+5 minutes */
+	else if (strcmp(new.instance, "root") == 0)
+	  new.max_life = 96;	/* 8 hours */
+	else if (krb_life_to_time(0, 162) >= 24*60*60)
 	  new.max_life = 162;     /* ca 100 hours */
 	else
 	  new.max_life = 255;     /* ca 21 hours (maximum) */
+
 	new.exp_date = time(0) + 2*(365*24*60*60); /* + ca 2 years */
 	new.attributes = 0;
 	get_maxlife(&new);
@@ -625,7 +649,7 @@ add_new_key(int argc, char **argv)
 	    }
 	} else
 	    printf("Error reading password; %s not added\n",argv[1]);
-	bzero((char *)&new, sizeof(new));
+	memset(&new, 0, sizeof(new));
 	if (!multiple)
 	    clean_up();
     }
@@ -634,6 +658,39 @@ add_new_key(int argc, char **argv)
     return;
 }
 
+void 
+del_entry(int argc, char **argv)
+{
+    int status;
+    Kadm_vals vals;
+
+    if (argc != 2) {
+	printf("Usage: del_entry username\n");
+	return;
+    }
+
+    if (setvals(&vals, argv[1]) != KADM_SUCCESS)
+	return;
+
+    if (princ_exists(vals.name, vals.instance, krbrlm) != PE_NO) {
+	/* get the admin's password */
+	if (get_admin_password() != GOOD_PW)
+	    return;
+	
+	if ((status = kadm_del(&vals)) == KADM_SUCCESS){
+	    printf("%s removed from database.\n", argv[1]);
+	}else{
+	    printf("kadm error: %s\n",error_message(status));
+	}
+	
+	if (!multiple)
+	    clean_up();
+    }
+    else
+	printf("kadmin: Principal does not exist.\n");
+    return;
+}
+
 void 
 get_entry(int argc, char **argv)
 {
@@ -646,13 +703,16 @@ get_entry(int argc, char **argv)
 	return;
     }
 
-    bzero(fields, sizeof(fields));
+    memset(fields, 0, sizeof(fields));
 
     SET_FIELD(KADM_NAME,fields);
     SET_FIELD(KADM_INST,fields);
     SET_FIELD(KADM_EXPDATE,fields);
     SET_FIELD(KADM_ATTR,fields);
     SET_FIELD(KADM_MAXLIFE,fields);
+#if 0
+    SET_FIELD(KADM_DESKEY,fields); 
+#endif
 
     if (setvals(&vals, argv[1]) != KADM_SUCCESS)
 	return;
@@ -688,7 +748,7 @@ mod_entry(int argc, char **argv)
 	return;
     }
 
-    bzero(fields, sizeof(fields));
+    memset(fields, 0, sizeof(fields));
 
     SET_FIELD(KADM_NAME,fields);
     SET_FIELD(KADM_INST,fields);
@@ -810,6 +870,14 @@ help(int argc, char **argv)
 	printf("You are also prompted for the default ticket");
 	printf(" lifetime, attributes\n");
 	printf("and expiration date (see the 'mod_entry' command).\n");
+    } else if (!strcmp(argv[1], "del_entry") ||
+	       !strcmp(argv[1], "del") ||
+	       !strcmp(argv[1], "delete")) {
+	printf("Usage: del_entry user_name.\n");
+	printf("\n");
+	printf("user_name is the name of a user whose");
+	printf(" entry you wish to delete.  Your\n");
+	printf("\"Admin\" password is prompted for. \n");
     } else if (!strcmp(argv[1], "get_entry") ||
 	       !strcmp(argv[1], "get")) {
 	printf("Usage: get_entry user_name.\n");
