@@ -30,7 +30,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kpasswd.c,v 1.13 1996/03/25 13:11:27 bg Exp $");
+RCSID("$Id: kpasswd.c,v 1.16 1996/06/14 09:44:47 assar Exp $");
 
 #ifdef NOENCRYPTION
 #define read_long_pw_string placebo_read_pw_string
@@ -64,9 +64,9 @@ main(int argc, char **argv)
     int c;
     char tktstring[MaxPathLen];
     
-    bzero(name, sizeof(name));
-    bzero(inst, sizeof(inst));
-    bzero(realm, sizeof(realm));
+    memset(name, 0, sizeof(name));
+    memset(inst, 0, sizeof(inst));
+    memset(realm, 0, sizeof(realm));
     
     if (krb_get_tf_fullname(TKT_FILE, default_name, default_inst, 
 			    default_realm) != KSUCCESS) {
@@ -130,8 +130,14 @@ main(int argc, char **argv)
 	}
 	use_default = 0;
     }
-    if (optind < argc)
-	usage(1);
+    if (optind < argc){
+	use_default = 0;
+	status = kname_parse(name, inst, realm, argv[optind]);
+	if(status != KSUCCESS){
+	    fprintf(stderr, "Kerberos error: %s\n", krb_get_err_text(status));
+	    exit(1);
+	}
+    }
 
     if (use_default) {
 	strcpy(name, default_name);
@@ -145,7 +151,7 @@ main(int argc, char **argv)
 	    strcpy(realm, default_realm);
     }
 
-    (void) sprintf(tktstring, "/tmp/tkt_cpw_%d",(int)getpid());
+    (void) sprintf(tktstring, TKT_ROOT "_cpw_%d",(int)getpid());
     krb_set_tkt_string(tktstring);
     
     if (get_pw_new_pwd(pword, sizeof(pword), name, inst, realm,
@@ -163,14 +169,14 @@ main(int argc, char **argv)
 
       des_string_to_key(pword, &newkey);
       status = kadm_change_pw_plain((unsigned char*)&newkey, pword, &pw_msg);
-      bzero(newkey, sizeof(newkey));
+      memset(newkey, 0, sizeof(newkey));
       
       if (status == KADM_INSECURE_PW)
 	fprintf(stderr, "%s: Insecure password: %s\n", argv[0], pw_msg);
       else if (status != KADM_SUCCESS)
 	com_err(argv[0], status, " attempting to change password.");
     }
-    bzero(pword, sizeof(pword));
+    memset(pword, 0, sizeof(pword));
 
     if (status != KADM_SUCCESS)
       fprintf(stderr,"Password NOT changed.\n");
