@@ -1,9 +1,8 @@
 /*
  * This software may now be redistributed outside the US.
  *
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kadmin/ksrvutil.c,v $
+ * $Id: ksrvutil.c,v 1.24 1996/06/14 09:44:55 assar Exp $
  *
- * $Locker:  $
  */
 
 /* 
@@ -61,41 +60,13 @@ char u_realm[REALM_SZ];
 
 int destroyp = FALSE;		/* Should the ticket file be destroyed? */
 
-static void get_default_principal(void)
-{
-  struct passwd *pw;
-  char *file;
-
-  if ((file =  getenv("KRBTKFILE")) == 0)
-    file = TKT_FILE;  
-
-  if(tf_init(file, R_TKT_FIL) == KSUCCESS){
-    tf_close();
-    if(krb_get_tf_realm(file, u_realm) == KSUCCESS
-       && tf_init(file, R_TKT_FIL) == KSUCCESS
-       && tf_get_pname(u_name) == KSUCCESS
-       && tf_get_pinst(u_inst) == KSUCCESS){
-      tf_close();
-      return;
-    }
-  }
-  pw=getpwuid(getuid());
-  strcpy(u_name, pw->pw_name);
-  strcpy(u_inst, "");
-  krb_get_lrealm(u_realm, 1);
-  if(strcmp(u_name, "root")){
-    strcpy(u_name, getenv("USER"));
-    strcpy(u_inst, "root");
-  }
-}
-
 static unsigned short
 get_mode(char *filename)
 {
     struct stat statbuf;
     unsigned short mode;
 
-    (void) bzero((char *)&statbuf, sizeof(statbuf));
+    memset(&statbuf, 0, sizeof(statbuf));
     
     if (stat(filename, &statbuf) < 0) 
 	mode = SRVTAB_MODE;
@@ -115,14 +86,14 @@ copy_keyfile(char *keyfile, char *backup_keyfile)
     int rcount;			/* for copying keyfiles */
     int try_again;
     
-    (void) bzero((char *)buf, sizeof(buf));
+    memset(buf, 0, sizeof(buf));
     
     do {
 	try_again = FALSE;
 	if ((keyfile_fd = open(keyfile, O_RDONLY, 0)) < 0) {
 	    if (errno != ENOENT) {
 		(void)fprintf(stderr, "%s: Unable to read %s: %s\n", progname, 
-			      keyfile, k_strerror(errno));
+			      keyfile, strerror(errno));
 		exit(1);
 	    }
 	    else {
@@ -131,13 +102,13 @@ copy_keyfile(char *keyfile, char *backup_keyfile)
 		     open(keyfile, 
 			  O_WRONLY | O_TRUNC | O_CREAT, SRVTAB_MODE)) < 0) {
 		    (void) fprintf(stderr, "%s: Unable to create %s: %s\n", 
-				   progname, keyfile, k_strerror(errno));
+				   progname, keyfile, strerror(errno));
 		    exit(1);
 		}
 		else
 		    if (close(keyfile_fd) < 0) {
 			(void) fprintf(stderr, "%s: Failure closing %s: %s\n",
-				       progname, keyfile, k_strerror(errno));
+				       progname, keyfile, strerror(errno));
 			exit(1);
 		    }
 	    }
@@ -150,29 +121,29 @@ copy_keyfile(char *keyfile, char *backup_keyfile)
 	 open(backup_keyfile, O_WRONLY | O_TRUNC | O_CREAT, 
 	      keyfile_mode)) < 0) {
 	(void) fprintf(stderr, "%s: Unable to write %s: %s\n", progname, 
-		       backup_keyfile, k_strerror(errno));
+		       backup_keyfile, strerror(errno));
 	exit(1);
     }
     do {
 	if ((rcount = read(keyfile_fd, (char *)buf, sizeof(buf))) < 0) {
 	    (void) fprintf(stderr, "%s: Error reading %s: %s\n", progname,
-			   keyfile, k_strerror(errno));
+			   keyfile, strerror(errno));
 	    exit(1);
 	}
 	if (rcount && (write(backup_keyfile_fd, buf, rcount) != rcount)) {
 	    (void) fprintf(stderr, "%s: Error writing %s: %s\n", progname,
-			   backup_keyfile, k_strerror(errno));
+			   backup_keyfile, strerror(errno));
 	    exit(1);
 	}
     } while (rcount);
     if (close(backup_keyfile_fd) < 0) {
 	(void) fprintf(stderr, "%s: Error closing %s: %s\n", progname,
-		       backup_keyfile, k_strerror(errno));
+		       backup_keyfile, strerror(errno));
 	exit(1);
     }
     if (close(keyfile_fd) < 0) {
 	(void) fprintf(stderr, "%s: Error closing %s: %s\n", progname,
-		       keyfile, k_strerror(errno));
+		       keyfile, strerror(errno));
 	exit(1);
     }
 }
@@ -190,12 +161,12 @@ leave(char *str, int x)
 void
 safe_read_stdin(char *prompt, char *buf, size_t size)
 {
-    (void) printf(prompt);
-    (void) fflush(stdout);
-    (void) bzero(buf, size);
+    printf(prompt);
+    fflush(stdout);
+    memset(buf, 0, size);
     if (read(0, buf, size - 1) < 0) {
 	(void) fprintf(stderr, "Failure reading from stdin: %s\n", 
-		       k_strerror(errno));
+		       strerror(errno));
 	leave((char *)NULL, 1);
     }
     fflush(stdin);
@@ -208,7 +179,7 @@ safe_write(char *filename, int fd, void *buf, size_t len)
 {
     if (write(fd, buf, len) != len) {
 	(void) fprintf(stderr, "%s: Failure writing to %s: %s\n", progname,
-		       filename, k_strerror(errno));
+		       filename, strerror(errno));
 	(void) close(fd);
 	leave("In progress srvtab in this file.", 1);
     }
@@ -287,7 +258,7 @@ get_svc_new_key(des_cblock *new_key, char *sname, char *sinst, char *srealm, cha
 	((status = kadm_init_link("changepw", KRB_MASTER, srealm)) == 
 	 KADM_SUCCESS)) {
 #ifdef NOENCRYPTION
-	(void) bzero((char *) new_key, sizeof(des_cblock));
+	memset(new_key, 0, sizeof(des_cblock));
 	new_key[0] = (unsigned char) 1;
 #else /* NOENCRYPTION */
 	(void) des_new_random_key(new_key);
@@ -307,7 +278,7 @@ get_key_from_password(des_cblock (*key), char *cellname)
 	leave("Error reading password.", 1);
 
 #ifdef NOENCRYPTION
-    (void) bzero((char *) key, sizeof(des_cblock));
+    memset(key, 0, sizeof(des_cblock));
     key[0] = (unsigned char) 1;
 #else /* NOENCRYPTION */
     if (strlen(cellname) == 0)
@@ -315,7 +286,7 @@ get_key_from_password(des_cblock (*key), char *cellname)
     else
       (void) afs_string_to_key(password, cellname, key);
 #endif /* NOENCRYPTION */
-    (void) bzero((char *)password, sizeof(password));
+    memset(password, 0, sizeof(password));
 }    
 
 static void
@@ -363,20 +334,23 @@ main(int argc, char **argv)
     char databuf[BUFSIZ];
     int first_printed = FALSE;	/* have we printed the first item? */
     
-    (void) bzero((char *)sname, sizeof(sname));
-    (void) bzero((char *)sinst, sizeof(sinst));
-    (void) bzero((char *)srealm, sizeof(srealm));
+    memset(sname, 0, sizeof(sname));
+    memset(sinst, 0, sizeof(sinst));
+    memset(srealm, 0, sizeof(srealm));
+    	  
+    memset(change_tkt, 0, sizeof(change_tkt));
+    memset(keyfile, 0, sizeof(keyfile));
+    memset(work_keyfile, 0, sizeof(work_keyfile));
+    memset(backup_keyfile, 0, sizeof(backup_keyfile));
+    memset(local_realm, 0, sizeof(local_realm));
     
-    (void) bzero((char *)change_tkt, sizeof(change_tkt));
-    (void) bzero((char *)keyfile, sizeof(keyfile));
-    (void) bzero((char *)work_keyfile, sizeof(work_keyfile));
-    (void) bzero((char *)backup_keyfile, sizeof(backup_keyfile));
-    (void) bzero((char *)local_realm, sizeof(local_realm));
-    
-    get_default_principal();
-
     progname=argv[0];
 
+    if (krb_get_default_principal(u_name, u_inst, u_realm) < 0) {
+	 fprintf (stderr, "%s: could not get default principal\n", progname);
+	 return 1;
+    }
+
     /* This is used only as a default for adding keys */
     if (krb_get_lrealm(local_realm, 1) != KSUCCESS)
 	(void) strcpy(local_realm, "NO.DEFAULT.REALM");
@@ -473,7 +447,7 @@ main(int argc, char **argv)
     if (change || list) {
 	if ((backup_keyfile_fd = open(backup_keyfile, O_RDONLY, 0)) < 0) {
 	  (void) fprintf(stderr, "%s: Unable to read %s: %s\n", progname,
-			   backup_keyfile, k_strerror(errno));
+			   backup_keyfile, strerror(errno));
 	    exit(1);
 	}
     }
@@ -483,7 +457,7 @@ main(int argc, char **argv)
 	     open(work_keyfile, O_WRONLY | O_CREAT | O_TRUNC, 
 		  SRVTAB_MODE)) < 0) {
 	    (void) fprintf(stderr, "%s: Unable to write %s: %s\n", progname,
-			   work_keyfile, k_strerror(errno));
+			   work_keyfile, strerror(errno));
 	    exit(1);
 	}
     }
@@ -491,7 +465,7 @@ main(int argc, char **argv)
 	if ((work_keyfile_fd =
 	     open(work_keyfile, O_APPEND | O_WRONLY, SRVTAB_MODE)) < 0) {
 	    (void) fprintf(stderr, "%s: Unable to open %s for append: %s\n",
-			   progname, work_keyfile, k_strerror(errno));
+			   progname, work_keyfile, strerror(errno));
 	    exit(1);
 	}
     }
@@ -500,7 +474,7 @@ main(int argc, char **argv)
 	     open(work_keyfile, O_RDWR | O_CREAT, SRVTAB_MODE)) < 0) {
 	     (void) fprintf(stderr, "%s: Unable to open %s for writing: %s\n",
 			    progname, work_keyfile,
-			    k_strerror(errno));
+			    strerror(errno));
 	     exit(1);
 	}
     }
@@ -532,7 +506,7 @@ main(int argc, char **argv)
 		(void) printf("\n");
 	    }
 	    else if (change) {
-		(void) sprintf(change_tkt, "/tmp/tkt_ksrvutil.%d",
+		(void) sprintf(change_tkt, TKT_ROOT "_ksrvutil.%d",
 			       (int)getpid());
 		krb_set_tkt_string(change_tkt);
 		destroyp = TRUE;
@@ -573,14 +547,14 @@ main(int argc, char **argv)
 					 srealm, keyfile)) == KADM_SUCCESS)
 			key_vno++;
 		    else {
-			(void) bcopy(old_key, new_key, sizeof(new_key));
-			(void) fprintf(stderr, "%s: Key NOT changed: %s\n",
-				       progname, krb_get_err_text(status));
+		        memcpy(new_key, old_key, sizeof(new_key));
+			fprintf(stderr, "%s: Key NOT changed: %s\n",
+				progname, krb_get_err_text(status));
 			change_this_key = FALSE;
 		    }
 		}
 		else 
-		    (void) bcopy(old_key, new_key, sizeof(new_key));
+		    (void) memcpy(new_key, old_key, sizeof(new_key));
 		append_srvtab(work_keyfile, work_keyfile_fd, 
 			      sname, sinst, srealm, key_vno, new_key);
 		if (key && change_this_key) {
@@ -612,14 +586,14 @@ main(int argc, char **argv)
 			else {
 			    (void)fprintf(stderr, 
 					  "%s: Unable to revert keyfile: %s\n",
-					  progname, k_strerror(errno));
+					  progname, strerror(errno));
 			    leave("", 1);
 			}
 		    }
 		}
 	    }
-	    bzero((char *)old_key, sizeof(des_cblock));
-	    bzero((char *)new_key, sizeof(des_cblock));
+	    memset(old_key, 0, sizeof(des_cblock));
+	    memset(new_key, 0, sizeof(des_cblock));
 	}
     }
     else if (add) {
@@ -665,20 +639,20 @@ main(int argc, char **argv)
     if (change || list) 
 	if (close(backup_keyfile_fd) < 0) {
 	    (void) fprintf(stderr, "%s: Failure closing %s: %s\n",
-			   progname, backup_keyfile, k_strerror(errno));
+			   progname, backup_keyfile, strerror(errno));
 	    (void) fprintf(stderr, "continuing...\n");
 	}
     
     if (change || add || get) {
 	if (close(work_keyfile_fd) < 0) {
 	    (void) fprintf(stderr, "%s: Failure closing %s: %s\n",
-			   progname, work_keyfile, k_strerror(errno));
+			   progname, work_keyfile, strerror(errno));
 	    exit(1);
 	}
 	if (rename(work_keyfile, keyfile) < 0) {
 	    (void) fprintf(stderr, "%s: Failure renaming %s to %s: %s\n",
 			   progname, work_keyfile, keyfile, 
-			   k_strerror(errno));
+			   strerror(errno));
 	    exit(1);
 	}
 	(void) chmod(backup_keyfile, keyfile_mode);
