@@ -1,7 +1,7 @@
 #include "kadm_locl.h"
 #include "ksrvutil.h"
 
-RCSID("$Id: ksrvutil_get.c,v 1.11 1996/03/25 13:11:28 bg Exp $");
+RCSID("$Id: ksrvutil_get.c,v 1.15 1996/06/16 00:19:41 assar Exp $");
 
 #define BAD_PW 1
 #define GOOD_PW 0
@@ -47,10 +47,10 @@ get_admin_password(char *myname, char *myinst, char *myrealm)
     }
     status = krb_get_pw_in_tkt(myname, myinst, myrealm, PWSERV_NAME, 
 			       KADM_SINST, ticket_life, admin_passwd);
-    bzero(admin_passwd, sizeof(admin_passwd));
+    memset(admin_passwd, 0, sizeof(admin_passwd));
     
     /* Initialize non shared random sequence from session key. */
-    bzero(&c, sizeof(c));
+    memset(&c, 0, sizeof(c));
     krb_get_cred(PWSERV_NAME, KADM_SINST, myrealm, &c);
     des_init_random_number_generator(&c.session);
   }
@@ -73,7 +73,7 @@ get_admin_password(char *myname, char *myinst, char *myrealm)
   }
   
   bad:
-  bzero(admin_passwd, sizeof(admin_passwd));
+  memset(admin_passwd, 0, sizeof(admin_passwd));
   (void) dest_tkt();
   return(BAD_PW);
 }
@@ -145,16 +145,26 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
 
   strncpy(chname, krb_get_phost(inst), sizeof(chname));
   if(strcmp(inst, chname))
-    fprintf(stderr, "Warning: hostname '%s' changed to '%s'\n", inst, chname);
+    fprintf(stderr, 
+	    "Warning: Are you sure `%s' should not be `%s'?\n",
+	    inst, chname);
     
-  bzero(&values, sizeof(values));
+  memset(&values, 0, sizeof(values));
   strcpy(values.name, name);
   strcpy(values.instance, inst);
   (void) des_new_random_key(&newkey);
-  bcopy((char *) newkey,(char *)&values.key_low,4);
-  bcopy((char *)(((int32_t *) newkey) + 1), (char *)&values.key_high,4);
+  values.key_low = (newkey[0] << 24) | (newkey[1] << 16)
+    | (newkey[2] << 8) | (newkey[3] << 0);
+  values.key_high = (newkey[4] << 24) | (newkey[5] << 16)
+    | (newkey[6] << 8) | (newkey[7] << 0);
+
+#if 0
+  memcpy(&values.key_low, newkey, 4);
+  memcpy(&values.key_high, ((char *)newkey) + 4, 4);
   values.key_low = htonl(values.key_low);
   values.key_high = htonl(values.key_high);
+#endif
+
   SET_FIELD(KADM_NAME,values.fields);
   SET_FIELD(KADM_INST,values.fields);
   SET_FIELD(KADM_DESKEY,values.fields);
@@ -173,7 +183,7 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
   /* get the key version number */
 
   strcpy(old_tktfile, tkt_string());
-  sprintf(new_tktfile, "/tmp/tkt_ksrvutil-get.%d", (int)getpid());
+  sprintf(new_tktfile, TKT_ROOT "_ksrvutil-get.%d", (int)getpid());
   krb_set_tkt_string(new_tktfile);
 
   ret = krb_get_in_tkt(name, inst, realm, name, inst,
@@ -199,7 +209,7 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
   /* Write the new key & c:o to the srvtab file */
 
   srvtab_put_key (fd, filename, name, inst, realm, kvno, newkey);
-  bzero(&newkey, sizeof(newkey));
+  memset(&newkey, 0, sizeof(newkey));
 
   fprintf (stderr, "Written %s.%s\n", name, inst);
 }
@@ -227,7 +237,7 @@ ksrvutil_kadm(int fd, char *filename, struct srv_ent *p)
     /*
      *  create ticket file and get admin tickets
      */
-    sprintf(tktstring, "/tmp/tkt_ksrvutil_%d", (int)getpid());
+    sprintf(tktstring, TKT_ROOT "_ksrvutil_%d", (int)getpid());
     krb_set_tkt_string(tktstring);
     destroyp = TRUE;
        
@@ -238,15 +248,9 @@ ksrvutil_kadm(int fd, char *filename, struct srv_ent *p)
       leave(NULL, 1);
     }
   }  
-  {
-    struct srv_ent *q;
-    
-    for(;p;){
-      get_srvtab_ent(fd, filename, p->name, p->inst, p->realm);
-      q=p;
-      p=p->next;
-      free(q);
-    }
+  for(;p;){
+    get_srvtab_ent(fd, filename, p->name, p->inst, p->realm);
+    p=p->next;
   }
   unlink(tktstring);
 }
