@@ -42,7 +42,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadm_stream.c,v 1.4 1996/03/25 13:10:28 bg Exp $");
+RCSID("$Id: kadm_stream.c,v 1.6 1996/05/29 23:24:15 assar Exp $");
 
 #define min(a,b) (((a) < (b)) ? (a) : (b))
 
@@ -52,7 +52,7 @@ build_field_header(u_char *cont, u_char **st)
             			/* stream */
 {
   *st = (u_char *) malloc (4);
-  bcopy((char *) cont, (char *) *st, 4);
+  memcpy((char *) *st, (char *) cont, 4);
   return 4;			/* return pointer to current stream location */
 }
 
@@ -64,7 +64,7 @@ check_field_header(u_char *st, u_char *cont, int maxlen)
 {
   if (4 > maxlen)
       return(-1);
-  bcopy((char *) st, (char *) cont, 4);
+  memcpy((char *) cont, (char *) st, 4);
   return 4;			/* return pointer to current stream location */
 }
 
@@ -75,7 +75,7 @@ vts_string(char *dat, u_char **st, int loc)
         			/* offset into the stream for current data */
 {
   *st = (u_char *) realloc ((char *)*st, (unsigned) (loc + strlen(dat) + 1));
-  bcopy(dat, (char *)(*st + loc), strlen(dat)+1);
+  memcpy(*st + loc, dat, strlen(dat)+1);
   return strlen(dat)+1;
 }
 
@@ -86,12 +86,15 @@ vts_short(u_int16_t dat, u_char **st, int loc)
             			/* a base pointer to the stream */
         			/* offset into the stream for current data */
 {
-  u_int16_t temp;			/* to hold the net order short */
-
-  temp = htons(dat);		/* convert to network order */
-  *st = (u_char *) realloc ((char *)*st, (unsigned)(loc + sizeof(u_int16_t)));
-  bcopy((char *) &temp, (char *)(*st + loc), sizeof(u_int16_t));
-  return sizeof(u_int16_t);
+    unsigned char *p;
+    p = realloc(*st, loc + 2);
+    if(p == NULL){
+	abort();
+    }
+    p[loc] = (dat >> 8) & 0xff;
+    p[loc+1] = dat & 0xff;
+    *st = p;
+    return 2;
 }
 
 static int
@@ -100,9 +103,13 @@ vts_char(u_char dat, u_char **st, int loc)
             			/* a base pointer to the stream */
         			/* offset into the stream for current data */
 {
-  *st = (u_char *) realloc ((char *)*st, (unsigned)(loc + sizeof(u_char)));
-  (*st)[loc] = (u_char) dat;
-  return 1;
+    unsigned char *p = realloc(*st, loc + 1);
+    if(p == NULL){
+	abort();
+    }
+    p[loc] = dat;
+    *st = p;
+    return 1;
 }
 
 int
@@ -111,12 +118,16 @@ vts_long(u_int32_t dat, u_char **st, int loc)
             			/* a base pointer to the stream */
         			/* offset into the stream for current data */
 {
-  u_int32_t temp;			/* to hold the net order short */
-
-  temp = htonl(dat);		/* convert to network order */
-  *st = (u_char *) realloc ((char *)*st, (unsigned)(loc + sizeof(u_int32_t)));
-  bcopy((char *) &temp, (char *)(*st + loc), sizeof(u_int32_t));
-  return sizeof(u_int32_t);
+    unsigned char *p = realloc(*st, loc + 4);
+    if(p == NULL){
+	abort();
+    }
+    p[loc] = (dat >> 24) & 0xff;
+    p[loc+1] = (dat >> 16) & 0xff;
+    p[loc+2] = (dat >> 8) & 0xff;
+    p[loc+3] = dat & 0xff;
+    *st = p;
+    return 4;
 }
     
 int
@@ -145,14 +156,11 @@ stv_short(u_char *st, u_int16_t *dat, int loc, int maxlen)
         			/* offset into the stream for current data */
            
 {
-  u_int16_t temp;			/* to hold the net order short */
-
-  if (loc + sizeof(temp) > maxlen)
-      return(-1);
-  /*bcopy((char *)((u_long)st+(u_long)loc), (char *) &temp, sizeof(u_short));*/
-  bcopy(st + loc, (char *) &temp, sizeof(temp));
-  *dat = ntohs(temp);		/* convert to network order */
-  return sizeof(temp);
+  if (maxlen - loc < 2)
+      return -1;
+  
+  *dat = (st[loc] << 8) | st[loc + 1];
+  return 2;
 }
 
 int
@@ -162,14 +170,11 @@ stv_long(u_char *st, u_int32_t *dat, int loc, int maxlen)
         			/* offset into the stream for current data */
            			/* maximum length of st */
 {
-  u_int32_t temp;			/* to hold the net order short */
-
-  if (loc + sizeof(temp) > maxlen)
-      return(-1);
-  /*bcopy((char *)((u_long)st+(u_long)loc), (char *) &temp, sizeof(u_long));*/
-  bcopy(st + loc, (char *) &temp, sizeof(temp));
-  *dat = ntohl(temp);		/* convert to network order */
-  return sizeof(temp);
+  if (maxlen - loc < 4)
+      return -1;
+  
+  *dat = (st[loc] << 24) | (st[loc+1] << 16) | (st[loc+2] << 8) | st[loc+3];
+  return 4;
 }
     
 static int
@@ -179,9 +184,10 @@ stv_char(u_char *st, u_char *dat, int loc, int maxlen)
         			/* offset into the stream for current data */
            
 {
-  if (loc + 1 > maxlen)
-      return(-1);
-  *dat = *(st + loc);
+  if (maxlen - loc < 1)
+      return -1;
+  
+  *dat = st[loc];
   return 1;
 }
 
@@ -243,7 +249,7 @@ stream_to_vals(u_char *dt_in, Kadm_vals *dt_out, int maxlen)
   register int vsloop, stsize;		/* loop counter, stream size */
   register int status;
 
-  bzero((char *) dt_out, sizeof(*dt_out));
+  memset(dt_out, 0, sizeof(*dt_out));
 
   stsize = check_field_header(dt_in, dt_out->fields, maxlen);
   if (stsize < 0)
