@@ -36,7 +36,7 @@ or implied warranty.
 
 #include <kdc.h>
 
-RCSID("$Id: krb_kdb_utils.c,v 1.12 1996/03/28 11:10:48 bg Exp $");
+RCSID("$Id: krb_kdb_utils.c,v 1.14 1996/05/29 23:24:25 assar Exp $");
 
 /* always try /.k for backwards compatibility */
 static char *master_key_files[] = { MKEYFILE, "/.k", NULL };
@@ -54,7 +54,7 @@ int kdb_new_get_master_key(des_cblock *key, des_key_schedule schedule)
       if(kfile < 0 && errno != ENOENT)
 	  fprintf(stderr, "Failed to open master key file \"%s\": %s\n", 
 		  *mkey,
-		  k_strerror(errno));
+		  strerror(errno));
       if(kfile >= 0)
 	  break;
   }
@@ -168,7 +168,7 @@ kdb_encrypt_key (des_cblock (*in), des_cblock (*out), des_cblock (*master_key),
 {
 
 #ifdef NOENCRYPTION
-  bcopy(in, out, sizeof(des_cblock));
+  memcpy(out, in, sizeof(des_cblock));
 #else
   des_pcbc_encrypt(in,out,(long)sizeof(des_cblock),master_key_sched,master_key,
  	e_d_flag);
@@ -221,11 +221,10 @@ kdb_verify_master_key (des_cblock *master_key, struct des_ks_struct *master_key_
 		   master_key, master_key_sched, DES_DECRYPT);
 
   /* the decrypted database key had better equal the master key */
-  n = bcmp((char *) master_key, (char *) key_from_db,
-	   sizeof(master_key));
+  n = memcmp(master_key, key_from_db, sizeof(master_key));
   /* this used to zero the master key here! */
-  bzero(key_from_db, sizeof(key_from_db));
-  bzero(principal_data, sizeof (principal_data));
+  memset(key_from_db, 0, sizeof(key_from_db));
+  memset(principal_data, 0, sizeof (principal_data));
 
   if (n && (out != (FILE *) NULL)) {
     fprintf(out, "\n\07\07verify_master_key: Invalid master key; ");
