@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_krbrlm.c,v 1.4 1995/10/24 10:14:22 bg Exp $");
+RCSID("$Id: get_krbrlm.c,v 1.7 1996/04/25 10:42:01 bg Exp $");
 
 /*
  * krb_get_lrealm takes a pointer to a string, and a number, n.  It fills
@@ -100,8 +100,19 @@ krb_get_lrealm(char *r, int n)
 	  *r = toupper(*t);
 	else
 	  *r = *t;
+      *r = 0;
       return(KSUCCESS);
     }
   else
     return(KFAILURE);
 }
+
+/* For SunOS5 compat. */
+char *
+krb_get_default_realm(void)
+{
+  static char local_realm[REALM_SZ]; /* local kerberos realm */
+  if (krb_get_lrealm(local_realm, 1) != KSUCCESS)
+    (void) strcpy(local_realm, "NO.DEFAULT.REALM");
+  return local_realm;
+}
