@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: k_gethostname.c,v 1.3 1996/03/25 13:09:30 bg Exp $");
+RCSID("$Id: k_gethostname.c,v 1.5 1996/06/01 12:11:59 assar Exp $");
 
 /*
  * Return the local host's name in "name", up to "namelen" characters.
@@ -42,6 +42,11 @@ RCSID("$Id: k_gethostname.c,v 1.3 1996/03/25 13:09:30 bg Exp $");
 int
 k_gethostname(char *name, int namelen)
 {
+#ifdef HAVE_GETHOSTBYNAME
     return gethostname(name, namelen);
-
+#else
+    name[namelen-1] = '\0';
+    strncpy (name, "some.random.host", namelen);
+    return name;
+#endif
 }
