@@ -1,7 +1,5 @@
 /*
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v $
- * $Author: d91-jda $
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v 1.23 1996/04/29 08:03:38 d91-jda Exp $ 
+ * $Id: krb.h,v 1.30 1996/06/14 09:44:31 assar Exp $
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -276,7 +274,7 @@ typedef struct msg_dat MSG_DAT;
  swab(((char *) x) +10,((char *)  _krb_swap_tmp) +4 ,2); \
  swab(((char *) x) +12,((char *)  _krb_swap_tmp) +2 ,2); \
  swab(((char *) x) +14,((char *)  _krb_swap_tmp) +0 ,2); \
- bcopy((char *)_krb_swap_tmp,(char *)x,16);\
+ memcpy(x, _krb_swap_tmp, 16);\
                             }
 
 #define     swap_u_12(x) {\
@@ -287,7 +285,7 @@ typedef struct msg_dat MSG_DAT;
  swab(((char *) x) +6, ((char *)  _krb_swap_tmp) +4 ,2); \
  swab(((char *) x) +8, ((char *)  _krb_swap_tmp) +2 ,2); \
  swab(((char *) x) +10,((char *)  _krb_swap_tmp) +0 ,2); \
- bcopy((char *)_krb_swap_tmp,(char *)x,12);\
+ memcpy(x, _krb_swap_tmp, 12);\
                             }
 
 #define     swap_C_Block(x) {\
@@ -296,7 +294,7 @@ typedef struct msg_dat MSG_DAT;
  swab(((char *) x) +2,((char *)  _krb_swap_tmp) +4 ,2); \
  swab(((char *) x) +4,((char *)  _krb_swap_tmp) +2 ,2); \
  swab(((char *) x) +6,((char *)  _krb_swap_tmp)    ,2); \
- bcopy((char *)_krb_swap_tmp,(char *)x,8);\
+ memcpy(x, _krb_swap_tmp, 8);\
                             }
 #define     swap_u_quad(x) {\
  u_int32_t   _krb_swap_tmp[4];\
@@ -304,7 +302,7 @@ typedef struct msg_dat MSG_DAT;
  swab(((char *) &x) +2,((char *)  _krb_swap_tmp) +4 ,2); \
  swab(((char *) &x) +4,((char *)  _krb_swap_tmp) +2 ,2); \
  swab(((char *) &x) +6,((char *)  _krb_swap_tmp)    ,2); \
- bcopy((char *)_krb_swap_tmp,(char *)&x,8);\
+ memcpy(x, _krb_swap_tmp, 8);\
                             }
 
 #define     swap_u_long(x) {\
@@ -355,7 +353,6 @@ int k_flock __P((int fd, int operation));
 struct tm;
 #endif
 struct tm *k_localtime __P((u_int32_t *));
-const char *k_strerror __P((int errnum));
 int k_getsockinst __P((int fd, char *inst));
 int k_getportbyname __P((const char *service, const char *proto, int default_port));
 
@@ -461,6 +458,10 @@ void cr_err_reply __P((KTEXT, char *, char *, char *, u_int32_t, u_int32_t, char
 void extract_ticket __P((KTEXT, int, char *, int *, int *, char *, KTEXT));
 void krb_set_tkt_string __P((char *));
 
+int krb_get_default_principal __P((char *, char *, char *));
+int krb_realm_parse __P((char *, int));
+int krb_verify_user __P((char*, char*, char*, char*, int, char *));
+
 void kset_logfile __P((char *));
 void set_logfile __P((char *));
 
