@@ -1,5 +1,4 @@
 /*
- *	$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/krbglue.c,v 1.1.1.1 1995/10/23 11:19:11 d91-jda Exp $
  *
  * Copyright 1988 by the Massachusetts Institute of Technology.
  *
@@ -142,7 +141,7 @@ get_krbrlm (r, n)
 char *r;
 int n;
 {
-    return krb_get_lream(r,n);
+    return krb_get_lrealm(r,n);
 }
 
 int
