@@ -26,11 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: recvauth.c,v 1.4 1996/03/25 13:09:53 bg Exp $");
-
-#include <sys/types.h>
-#include <netinet/in.h>
-#include <syslog.h>
+RCSID("$Id: recvauth.c,v 1.8 1996/06/04 00:42:37 joda Exp $");
 
 /*
  * If the protocol changes, you will need to change the version string
@@ -121,6 +117,16 @@ RCSID("$Id: recvauth.c,v 1.4 1996/03/25 13:09:53 bg Exp $");
  * other error code is returned.
  */
 
+static int
+send_error_reply(int fd)
+{
+    char tmp[4] = { 255, 255, 255, 255 };
+    if(krb_net_write(fd, tmp, 4) != 4)
+	return -1;
+    return 0;
+}
+
+
 #ifndef max
 #define	max(a,b) (((a) > (b)) ? (a) : (b))
 #endif /* max */
@@ -163,7 +169,7 @@ krb_recvauth(int32_t options, int fd, KTEXT ticket, char *service, char *instanc
 	old_vers = 1;
 
 	/* copy what we have read into tmp_buf */
-	(void) bcopy(krb_vers, (char *) tmp_buf, KRB_SENDAUTH_VLEN);
+	(void) memcpy((char *) tmp_buf, krb_vers, KRB_SENDAUTH_VLEN);
 
 	/* search for space, and make it a null */
 	for (i = 0; i < KRB_SENDAUTH_VLEN; i++)
@@ -208,7 +214,7 @@ krb_recvauth(int32_t options, int fd, KTEXT ticket, char *service, char *instanc
 	}
 	ticket->length = tkt_len;
 	/* copy the ticket into the struct */
-	(void) bcopy(cp, (char *) ticket->dat, ticket->length);
+	(void) memcpy((char *) ticket->dat, cp, ticket->length);
 
     } else {
 	/* read the application version string */
@@ -218,16 +224,19 @@ krb_recvauth(int32_t options, int fd, KTEXT ticket, char *service, char *instanc
 	version[KRB_SENDAUTH_VLEN] = '\0';
 
 	/* get the length of the ticket */
-	if (krb_net_read(fd, (char *)&tkt_len, sizeof(tkt_len)) !=
-	    sizeof(tkt_len))
-	    return(errno);
+	{
+	    char tmp[4];
+	    if (krb_net_read(fd, tmp, 4) != 4)
+		return(errno);
+	    get_int(tmp, &ticket->length, 4, 0);
+	}
     
 	/* sanity check */
-	ticket->length = ntohl((unsigned long)tkt_len);
 	if ((ticket->length <= 0) || (ticket->length > MAX_KTXT_LEN)) {
 	    if (options & KOPT_DO_MUTUAL) {
-		rem = KFAILURE;
-		goto mutual_fail;
+		if(send_error_reply(fd))
+		    return errno;
+		return KFAILURE;
 	    } else
 		return(KFAILURE); /* XXX there may still be junk on the fd? */
 	}
@@ -248,46 +257,34 @@ krb_recvauth(int32_t options, int fd, KTEXT ticket, char *service, char *instanc
 
     /* if we are doing mutual auth, compose a response */
     if (options & KOPT_DO_MUTUAL) {
-	if (rem != KSUCCESS)
+	if (rem != KSUCCESS){
 	    /* the krb_rd_req failed */
-	    goto mutual_fail;
-
+	    if(send_error_reply(fd))
+		return errno;
+	    return rem;
+	}
+	
 	/* add one to the (formerly) sealed checksum, and re-seal it
 	   for return to the client */
-	cksum = kdata->checksum + 1;
-	cksum = htonl(cksum);
+	{ 
+	    unsigned char cs[4];
+	    put_int(kdata->checksum + 1, cs, 4);
 #ifndef NOENCRYPTION
-	des_key_sched(&kdata->session,schedule);
+	    des_key_sched(&kdata->session,schedule);
 #endif
-	priv_len = krb_mk_priv((unsigned char *)&cksum,
-			       tmp_buf,
-			       (unsigned long) sizeof(cksum),
-			       schedule,
-			       &kdata->session,
-			       laddr,
-			       faddr);
-	if (priv_len < 0) {
-	    /* re-sealing failed; notify the client */
-	    rem = KFAILURE;	 /* XXX */
-mutual_fail:
-	    priv_len = -1;
-	    tkt_len = htonl((unsigned long) priv_len);
-	    /* a length of -1 is interpreted as an authentication
-	       failure by the client */
-	    if ((cc = krb_net_write(fd, (char *)&tkt_len, sizeof(tkt_len)))
-		!= sizeof(tkt_len))
-		return(cc);
-	    return(rem);
-	} else {
-	    /* re-sealing succeeded, send the private message */
-	    tkt_len = htonl((unsigned long)priv_len);
-	    if ((cc = krb_net_write(fd, (char *)&tkt_len, sizeof(tkt_len)))
-		 != sizeof(tkt_len))
-		return(cc);
-	    if ((cc = krb_net_write(fd, (char *)tmp_buf, (int) priv_len))
-		!= (int) priv_len)
-		return(cc);
+	    priv_len = krb_mk_priv(cs, 
+				   tmp_buf+4, 
+				   4,
+				   schedule,
+				   &kdata->session,
+				   laddr,
+				   faddr);
 	}
+	/* mk_priv will never fail */
+	priv_len += put_int(priv_len, tmp_buf, 4);
+	
+	if((cc = krb_net_write(fd, tmp_buf, priv_len)) != priv_len)
+	    return cc;
     }
     return(rem);
 }
