@@ -1,8 +1,10 @@
-/* $Id: roken.h,v 1.7 1996/05/04 02:02:25 d91-jda Exp $ */
+/* $Id: roken.h,v 1.10 1996/06/08 21:53:03 joda Exp $ */
 
 #ifndef __ROKEN_H__
 #define __ROKEN_H__
 
+#include <stdlib.h>
+#include <string.h>
 #include <sys/types.h>
 #include <netinet/in.h>
 
@@ -14,6 +16,10 @@ int putenv(const char *string);
 int setenv(const char *var, const char *val, int rewrite);
 #endif
 
+#ifndef HAVE_UNSETENV
+void unsetenv(const char *name);
+#endif
+
 #ifndef HAVE_GETUSERSHELL
 char *getusershell(void);
 #endif
@@ -31,10 +37,6 @@ typedef RETSIGTYPE (*SigAction)(/* int??? */);
 SigAction signal(int iSig, SigAction pAction); /* BSD compatible */
 #endif
 
-#ifndef HAVE_SNPRINTF
-int snprintf(char *s, int n, const char *fmt, ...);
-#endif
-
 #ifndef HAVE_STRERROR
 char *strerror(int eno);
 #endif
@@ -43,6 +45,10 @@ char *strerror(int eno);
 char *hstrerror(int herr);
 #endif
 
+#ifndef HAVE_HERROR
+void herror(char *s);
+#endif
+
 #ifndef HAVE_INET_ATON
 /* Minimal implementation of inet_aton. Doesn't handle hex numbers. */
 #ifndef __GNUC__
@@ -54,4 +60,15 @@ int inet_aton(char *cp, struct in_addr *adr);
 char* getcwd(char *path, int size);
 #endif
 
+#ifndef HAVE_GETENT
+int getent(char *cp, char *name);
+#endif
+
+#ifndef HAVE_GETSTR
+char *getstr(char *id, char **cpp);
+#endif
+
+#include <pwd.h>
+struct passwd *k_getpwnam (char *user);
+
 #endif /*  __ROKEN_H__ */
