@@ -19,7 +19,7 @@ provided "as is" without express or implied warranty.
 
 #include "slav_locl.h"
 
-RCSID("$Id: kprop.c,v 1.11 1996/03/25 13:08:23 bg Exp $");
+RCSID("$Id: kprop.c,v 1.14 1996/06/05 00:06:54 joda Exp $");
 
 #include "kprop.h"
 
@@ -92,7 +92,7 @@ int get_slaves(struct slave_host **psl, char *file, time_t ok_mtime)
 		    file);
 	    exit(-1);
 	}
-	bzero( (*th) , (sizeof(struct slave_host)) );
+	memset(*th, 0, sizeof(struct slave_host));
 	(*th)->name = malloc(strlen(namebuf) + 1);
 	if (!(*th)->name) {
 	    fprintf(stderr, "No memory reading host list from '%s'.\n",
@@ -111,7 +111,7 @@ int get_slaves(struct slave_host **psl, char *file, time_t ok_mtime)
 	strcpy((*th)->instance, inst);
 	/* what a concept, slave servers in different realms! */
 	(*th)->realm = my_realm;
-	bcopy(host->h_addr, (char *)&(*th)->net_addr, sizeof(host->h_addr));
+	memcpy(&(*th)->net_addr, host->h_addr, sizeof(host->h_addr));
 	(*th)->not_time_yet = 0;
 	(*th)->succeeded = 0;
 	(*th)->next = NULL;
@@ -140,7 +140,6 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 {
     u_char buf[KPROP_BUFSIZ];
     u_char obuf[KPROP_BUFSIZ + 64	/* leave room for private msg overhead */ ];
-    struct servent *sp;
     struct sockaddr_in sin, my_sin;
     int     i, n, s;
     struct slave_host *cs;	/* current slave */
@@ -160,14 +159,9 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
     (void) mktemp(tkstring);
     krb_set_tkt_string(tkstring);
     
-    if ((sp = getservbyname("krb_prop", "tcp")) == 0) {
-	fprintf(stderr, "tcp/krb_prop: service unknown.\n");
-	exit(1);
-    }
-
-    bzero(&sin, sizeof sin);
+    memset(&sin, 0, sizeof sin);
     sin.sin_family = AF_INET;
-    sin.sin_port = sp->s_port;
+    sin.sin_port = k_getportbyname ("krb_prop", "tcp", htons(754));
     sin.sin_addr.s_addr = INADDR_ANY;
 
     strcpy(path, fslv);
@@ -184,7 +178,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 		    perror("kprop: socket");
 		    exit(1);
 		}
-		bcopy(&cs->net_addr, &sin.sin_addr,
+		memcpy(&sin.sin_addr, &cs->net_addr, 
 		      sizeof cs->net_addr);
 
 		if (connect(s, (struct sockaddr *) &sin, sizeof sin) < 0) {
@@ -195,7 +189,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 		}
 		
 		/* for krb_mk_{priv, safe} */
-		bzero (&my_sin, sizeof my_sin);
+		memset(&my_sin, 0, sizeof my_sin);
 		n = sizeof my_sin;
 		if (getsockname (s, (struct sockaddr *) &my_sin, &n) != 0) {
 		    fprintf (stderr, "kprop: can't get socketname.");
@@ -281,7 +275,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 		    continue;	/*** NEXT SLAVE ***/
 		}
 #ifdef NOENCRYPTION
-		bzero((char *)session_sched, sizeof(session_sched));
+		memset(session_sched, 0, sizeof(session_sched));
 #else
 		if (des_key_sched (&cred.session, session_sched)) {
 		    fprintf (stderr, "%s: can't make key schedule.",
@@ -393,6 +387,20 @@ punt:
     return (1);
 }
 
+static void
+usage(void)
+{
+    /* already got floc and fslv, what is this? */
+    fprintf(stderr,
+	    "\nUsage: kprop [-force] [-realm realm] [-private"
+#ifdef not_safe_yet
+	    "|-safe|-clear"
+#endif
+	    "] [data_file [slaves_file]]\n\n");
+    exit(1);
+}
+
+
 int
 main(int argc, char **argv)
 {
@@ -435,7 +443,7 @@ main(int argc, char **argv)
 	    if (i < argc)
 		strcpy(my_realm, argv[i]);
 	    else
-		goto usage;
+		usage();
 	} else if (strcmp (argv[i], "-force") == 0)
 	    force_flag++;
 	else {
@@ -451,18 +459,15 @@ main(int argc, char **argv)
 	else {
 	  if (fslv == (char *) NULL)
 	    fslv = argv[i];
-	  else {
-	  usage:
-		  /* already got floc and fslv, what is this? */
-	    fprintf(stderr,
-		    "\nUsage: kprop [-force] [-realm realm] [-private|-safe|-clear] data_file slaves_file\n\n");
-	    exit(1);
-	  }
+	  else 
+	      usage();	
 	}
       }
-    if ((floc == (char *)NULL) || (fslv == (char *)NULL))
-	    goto usage;
-    
+    if(floc == NULL)
+	floc = DB_DIR "/slave_dump";
+    if(fslv == NULL)
+	fslv = DB_DIR "/slaves";
+	
     if ((floc_ok = (char *) malloc(strlen(floc) + strlen(ok) + 1))
 	== NULL) {
 	Death(floc);
