@@ -1,7 +1,5 @@
 /*
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/error_message.c,v 1.4 1996/03/10 15:12:45 assar Exp $
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/error_message.c,v $
- * $Locker:  $
+ * $Id: error_message.c,v 1.5 1996/06/12 21:29:38 bg Exp $
  *
  * Copyright 1987 by the Student Information Processing Board
  * of the Massachusetts Institute of Technology
@@ -21,7 +19,7 @@
 
 #if 0
 static const char rcsid[] =
-    "$Id: error_message.c,v 1.4 1996/03/10 15:12:45 assar Exp $";
+    "$Id: error_message.c,v 1.5 1996/06/12 21:29:38 bg Exp $";
 static const char copyright[] =
     "Copyright 1986, 1987, 1988 by the Student Information Processing Board\nand the department of Information Systems\nof the Massachusetts Institute of Technology";
 #endif
