@@ -26,7 +26,7 @@ void ss_page_stdin(void);
 
 void ss_help(int argc, const char * const *argv, int sci_idx, void *info_ptr)
 {
-    char buffer[MAXPATHLEN];
+    char buffer[MaxPathLen];
     char const *request_name;
     int code;
     int fd, child;
@@ -66,7 +66,7 @@ void ss_help(int argc, const char * const *argv, int sci_idx, void *info_ptr)
 	if ((fd = open(&buffer[0], O_RDONLY, 0)) >= 0) goto got_it;
     }
     if ((fd = open(&buffer[0], O_RDONLY, 0)) < 0) {
-	char buf[MAXPATHLEN];
+	char buf[MaxPathLen];
 	strcpy(buf, "No info found for ");
 	strcat(buf, argv[1]);
 	ss_perror(sci_idx, 0, buf);
